window.wp = window.wp || {};
window.Huddle = window.Huddle || {};
/**
 * Add our approval default
 */
_.extend( Huddle.Image.prototype.defaults, {
    approved: false
});

/**
 * Extend the original image model
 * Adds new approve method
 */
_.extend( Huddle.Image.prototype, {
    /**
     * Store a custom action for approving images
     *
     * @param attributes {object} Attributes to update
     * @param options {object} Options to extend from
     */
    approve: function ( attributes, options ) {
        options = _.defaults((options || {}), {
            data: {
                nonce: phApproval.phNonce, // pass our custom nonce
                action: 'ph_approve_image' // our ajax action
            }
        });
        return Backbone.Model.prototype.save.call(this, attributes, options);
    }
});
/**
 * Add our approval default
 */
_.extend( Huddle.Permissions.prototype.defaults, {
    allowApprovals: false
});

/**
 * Hook into permissions model initialize method
 */
wp.hooks.addAction( 'Huddle.Permissions.initialize', function( model ){
    model.phPermissionApproveInitialize();
});

/**
 * Extend the original image model
 * Adds new approve method
 */
_.extend( Huddle.Permissions.prototype, {

    /**
     * Add approval listeners
     */
    phPermissionApproveInitialize: function() {
        // check approvals
        this.allowApprovals();

        // set after identify success
        this.listenTo( Huddle.Event, 'identifySuccess', this.allowApprovals );
    },

    /**
     * Allow approvals/unapprovals if allowed
     */
    allowApprovals: function() {
        this.set({
            'allowApprovals': false,
            'allowUnapprovals': false
        });

        if ( Huddle.options.project.allow_approve != 'off' ) {
            this.set({
                'allowApprovals': true
            });
        }

        if ( Huddle.options.project.allow_unapprove != 'off' ) {
            this.set({
                'allowUnApprovals': true
            });
        }
    }

} );
/**
 * Hook into ControlsView initialize method
 */
wp.hooks.addAction('Huddle.ImageCollection.initialize', function( collection ){
    collection.phAddApproveListeners();
});

/**
 * Extend the original image collection
 * Adds new methods
 */
_.extend( Huddle.ImageCollection.prototype, {

    /**
     * Add approval listeners
     */
    phAddApproveListeners: function() {
        this.listenTo( this, 'approveImage', this.phSaveApproval );
    },

    /**
     * Save approval meta
     *
     * @param image Image model to update
     */
    phSaveApproval: function( image ) {
        image.approve( undefined, {
            success: function ( model, response ) {
                if ( response.success != false ) {
                    toastr.remove();
                    if ( model.attributes.approved ) {
                        toastr.success( Huddle.translations.approved, {timeOut: 2000} );
                    } else {
                        toastr.info( Huddle.translations.unapproved, {timeOut: 2000} );
                    }
                }
            },
            error: function ( model, xhr ) {
                console.error( xhr );
                toastr.error( 'Something went wrong. Please refresh the page and try again.' );
            }
        } );
    }

});
/**
 * Approve Button View
 *
 * @since 1.0.0
 */
Huddle.ApproveButtonView = Huddle.View.extend({
    template: wp.template('approve-button'),
    tagName: 'button',

    /**
     * Set Button attributes
     * @returns {object} attributes to add to the button
     */
    attributes: function () {
        return {
            class: this.classes(),
            'data-mode': 'bottom',
            'data-tip': this.dataTip()
        };
    },

    /**
     * Create class attribute
     *
     * @returns {string}
     */
    classes: function () {
        var classes = 'ph-approve-button ph-approve-image ';
        classes += this.model.get('approved') ? 'ph-approved' : 'ph-pending';
        return classes;
    },

    /**
     * Create tooltip attribute
     *
     * @returns {string}
     */
    dataTip: function () {
        if (this.model.get('approved')) {
            return Huddle.translations.unapprove_image ? Huddle.translations.unapprove_image : 'UnApprove Image';
        } else {
            return Huddle.translations.unapprove_image ? Huddle.translations.approve_image : 'Approve Image';
        }
    },

    events: {
        'click': 'approve'
    },

    identityCheck: false,

    initialize: function () {
        this.listenTo(this.model, 'change:approved', this.changeApproval);
        this.listenTo(this.model, 'approveImage', this.addLoading);
        this.listenTo(this.model, 'identifySuccess', this.doApproval);

        // broadcast init
        wp.hooks.doAction('Huddle.ApproveButtonView.initialize', this);
    },

    /**
     * Adds loading class to button
     */
    addLoading: function () {
        this.$el.addClass('ph-spinner ph-spinner-dark');
    },

    /**
     * Approval change handler
     */
    changeApproval: function () {
        this.renderTransition(_.bind(this.swapApproval, this));
        if ( this.model.get('approved') ) {
            toastr.success(Huddle.translations.approved);
        } else {
            toastr.info(Huddle.translations.unapproved);
        }
    },

    doApproval: function () {
        this.identityChecking && this.approve();
    },

    /**
     * Make transition smooth
     *
     * @param callback What to change before smooth transition
     */
    renderTransition: function (callback) {
        // store original width
        this.$el.data('oWidth', this.$el.width());

        // callback function
        callback && callback();

        // find new width and store in data
        this.$el.css('width', 'auto').data('nWidth', this.$el.outerWidth());

        // set old width
        this.$el.width(this.$el.data('oWidth'));

        // animate new width and re-render
        this.$el.animate({width: this.$el.data('nWidth')}, 500, 'easeOutCubic', _.bind(function () {
            this.$el.css({'width': 'auto'}).removeClass('width-transition spinner');
            this.render();
        }, this));
    },

    /**
     * Changes button approval html
     */
    swapApproval: function () {
        if (this.model.get('approved')) {
            this.$el.addClass('ph-approved');
            // this.$el.removeClass('ph-pending');
            this.$('.ph-button-text').html(Huddle.translations.unapprove);
        } else {
            // this.$el.addClass('ph-pending');
            this.$el.removeClass('ph-approved');
            this.$('.ph-button-text').html(Huddle.translations.approve);
        }

        // update attributes
        this.$el.attr(_.extend({}, _.result(this, 'attributes')));
    },

    /**
     * Change approval in model
     */
    approve: function () {
        if (!Huddle.permissions.get('allowComments')) {
            toastr.info(this.model.get('approved') ? Huddle.translations.cant_approve : Huddle.translations.cant_approve);
            return false;
        }

        // if it's approved and unapprovals aren't allowed, do nothing
        if (this.model.get('approved') && !Huddle.permissions.get('allowUnApprovals')) {
            toastr.info(Huddle.translations.cant_unapprove);
            return false;
        }

        // if it's approved and unapprovals aren't allowed, do nothing
        if (!this.model.get('approved') && !Huddle.permissions.get('allowApprovals')) {
            toastr.info(Huddle.translations.cant_approve);
            return false;
        }

        // validate user data
        if (!Huddle.user.attributes.user_email) {
            this.identityChecking = true;
            Huddle.Event.trigger('requireIdentity', this.model);
            return false;
        }

        // confirm approval
        this.confirmApproval(false, _.bind(this.approveWhich, this));
    },

    approveWhich: function (options, value) {
        var approval = !this.model.get('approved');

        if (value.approve_project) {
            // save in db
            Huddle.container.model.save({
                'approved': approval
            }, {
                url: Huddle.container.model.urlRoot + '/' + this.model.get('id') + '/approve'
            });
            // change all images in collection
            this.model.collection.forEach(_.bind(function (model, index) {
                model.set('approved', approval);
            }, this));
        } else {
            this.model.save({
                'approved': approval
            }, {
                url: this.model.urlRoot + '/' + this.model.get('id') + '/approve'
            });
        }
    },

    /**
     * Confirm approval dialog
     *
     * @param options Callback options
     * @param callback Callback function
     */
    confirmApproval: function (options, callback) {
        var t             = Huddle.translations,
            approveText   = this.model.get('approved') ? t.unapprove : t.approve,
            approveString = this.model.get('approved') && t ? t.confirmUnApprove : t.confirmApprove;

        // add image name
        var tags = {
            approval_status: approveText.toLowerCase(),
            image_number: this.model.collection.length - 1,
            image_name: this.model.get('title'),
            project_name: Huddle.container.model.get('name'),
            terms: '<u class="toggle-terms">' + t.approveCheckboxLink + '</u>',
            user_name: '<strong>' + Huddle.user.get('display_name') + '</strong>'
        };

        // replace any tags with variables
        var approveReplaced = approveString.replace(/\{\{(.*?)\}\}/g, function (match, token) {
            return tags[token];
        });

        // replace any tags with variables
        var termsReplaced = t.approveCheckbox.replace(/\{\{(.*?)\}\}/g, function (match, token) {
            return tags[token];
        });

        // replace any tags with variables
        var projectReplaced = t.approveProject.replace(/\{\{(.*?)\}\}/g, function (match, token) {
            return tags[token];
        });

        var vexOptions = {
            className: 'vex-theme-dialog vex-left-buttons',
            showCloseButton: true,
            message: approveReplaced,
            afterOpen: function ($vexContent) {
                $vexContent.find('.toggle-terms').click(function () {
                    jQuery('.ph-terms').slideToggle('fast');
                });
                $vexContent.find('.approve-option').appendTo('.vex-dialog-buttons');
            },
            callback: function (value) {
                if (!value) return false;
                callback && callback(options, value);
            }
        };

        // options
        var checked = Huddle.options.global.approval_type === 'project' ? 'checked' : '';
        var hidden  = Huddle.options.global.approval_type === 'project' ? 'ph-hidden' : '';

        vexOptions.input = '';
        if ( this.model.collection.length > 1 ) {
            vexOptions.input += "<div class='approve-option " + hidden +"'><input type='checkbox' name='approve_project' " + checked + "/><label>" + projectReplaced + "</label></div>";
        }
        if (parseInt(Huddle.options.global.require_terms)) {
            vexOptions.input += "<div class='terms'><input type='checkbox' required name='terms' /><label>" + termsReplaced + "</label></div>";
            vexOptions.input += "<div class='ph-terms'>" + t.approveTerms + "</div>";
        }

        // confirm approval
        if ( this.model.collection.length > 1 && Huddle.options.global.approval_type !== 'project' ) {
            vex.dialog.alert(vexOptions);
        } else {
            vex.dialog.open(vexOptions);
        }
    }
});
/**
 * Holds the Approve Button
 *
 * @since 1.0.0
 */
Huddle.ApproveContainerView = Huddle.View.extend({
    className: 'ph-approval-wrap',
    tagName: 'span',

    initialize: function () {
        this.listenTo(Huddle.state, 'change:image', this.setView);
    },

    ready: function() {
        this.$el.find('[data-tip]').tipr({
            'speed': 300
        });
    },

    buttonDisabled: function() {
        var options = Huddle.options.project;
        return options.allow_approve === 'off' && options.allow_unapprove === 'off';
    },

    /**
     * Adds the approval button with the right image state
     *
     * @param state State model
     */
    setView: function (state) {
        // don't show if completely disabled
        if ( this.buttonDisabled() ) {
            return;
        }
        this.views.set(new Huddle.ApproveButtonView({
            model: this.model.images.get(state.get('image'))
        }));
    }
});
/**
 * Hook into ControlsView initialize method
 */
wp.hooks.addAction('Huddle.ControlBarView.initialize', function (view) {
    view.phApproveInitialize();
});

/**
 * Extend the original image view
 * Adds new events, subviews and methods
 */
_.extend(Huddle.ControlBarView.prototype, {
    // add approval button sub view
    phApproveInitialize: function () {
        this.views.add('.project-controls', new Huddle.ApproveContainerView({
            model: this.model
        }));
    }
});
/**
 * Hook into ControlsView initialize method
 */
wp.hooks.addAction('Huddle.ImageThumbView.initialize', function( view ){
    view.phApproveListeners();
});

/**
 * Extend the original image view
 * Adds new events, subviews and methods
 */
_.extend( Huddle.ImageThumbView.prototype, {
    phApproveListeners: function() {
        // when image is approved or unapproved, re-render
        this.listenTo( this.model, 'change:approved', this.render );
    }
});
/**
 * Hook into ControlsView initialize method
 */
wp.hooks.addAction('Huddle.ImageTrayView.initialize', function (view) {
    view.approvalsInit();
});

/**
 * Extend the original image view
 * Adds new events, subviews and methods
 */
_.extend(Huddle.ImageTrayView.prototype, {
    approvalsInit: function () {
        // add filter view
        this.views.add('.ph-filter', new Huddle.ImageFilterView({
            model: this.model
        }));

        this.listenTo(this.model, 'change:filter', this.filter);
        this.listenTo(this.model.images, 'change:approved', this.filter);
    },

    images: [],

    filter: function () {
        this.images = [];
        this['filter' + _(this.model.get('filter')).capitalize()]();
        this.setImages();
    },

    setImages: function () {
        if (this.images.length) {
            this.views.set('#ph-thumb-nav-inner', this.images);
        } else {
            console.log('none');
            this.views.set('#ph-thumb-nav-inner', new Huddle.NoImagesView({
                model: this.model
            }))
        }
    },

    filterApproved: function () {
        _.each(this.model.images.where({approved: true}), function (image) {
            this.images.push(new Huddle.ImageThumbView({
                model: image
            }));
        }, this);
    },

    filterUnapproved: function () {
        _.each(this.model.images.where({approved: false}), function (image) {
            this.images.push(new Huddle.ImageThumbView({
                model: image
            }));
        }, this);
    },

    filterAll: function () {
        _.each(this.model.images.models, function (image) {
            this.images.push(new Huddle.ImageThumbView({
                model: image
            }));
        }, this);
    }
});

Huddle.ImageFilterView = Huddle.View.extend({
    template : wp.template('image-filter'),
    className: 'ph-image-filter-dropdown-container',

    events: {
        'click'   : 'toggle',
        'click li': 'sort'
    },

    triggers: {
        'change:filter': 'render'
    },

    toggle: function () {
        this.$el.toggleClass('ph-show');
    },

    sort: function (e) {
        this.model.set('filter', jQuery(e.target).data('sort'));
    }
});

Huddle.NoImagesView = Huddle.View.extend({
    className: 'ph-none-approved',
    template: wp.template('no-images')
});