/**
 * Hook into ControlsView initialize method
 */
wp.hooks.addAction('Huddle.ImageTrayView.initialize', function (view) {
    view.approvalsInit();
});

/**
 * Extend the original image view
 * Adds new events, subviews and methods
 */
_.extend(Huddle.ImageTrayView.prototype, {
    approvalsInit: function () {
        // add filter view
        this.views.add('.ph-filter', new Huddle.ImageFilterView({
            model: this.model
        }));

        this.listenTo(this.model, 'change:filter', this.filter);
        this.listenTo(this.model.images, 'change:approved', this.filter);
    },

    images: [],

    filter: function () {
        this.images = [];
        this['filter' + _(this.model.get('filter')).capitalize()]();
        this.setImages();
    },

    setImages: function () {
        if (this.images.length) {
            this.views.set('#ph-thumb-nav-inner', this.images);
        } else {
            console.log('none');
            this.views.set('#ph-thumb-nav-inner', new Huddle.NoImagesView({
                model: this.model
            }))
        }
    },

    filterApproved: function () {
        _.each(this.model.images.where({approved: true}), function (image) {
            this.images.push(new Huddle.ImageThumbView({
                model: image
            }));
        }, this);
    },

    filterUnapproved: function () {
        _.each(this.model.images.where({approved: false}), function (image) {
            this.images.push(new Huddle.ImageThumbView({
                model: image
            }));
        }, this);
    },

    filterAll: function () {
        _.each(this.model.images.models, function (image) {
            this.images.push(new Huddle.ImageThumbView({
                model: image
            }));
        }, this);
    }
});

Huddle.ImageFilterView = Huddle.View.extend({
    template : wp.template('image-filter'),
    className: 'ph-image-filter-dropdown-container',

    events: {
        'click'   : 'toggle',
        'click li': 'sort'
    },

    triggers: {
        'change:filter': 'render'
    },

    toggle: function () {
        this.$el.toggleClass('ph-show');
    },

    sort: function (e) {
        this.model.set('filter', jQuery(e.target).data('sort'));
    }
});

Huddle.NoImagesView = Huddle.View.extend({
    className: 'ph-none-approved',
    template: wp.template('no-images')
});