<?php
/**
 * Mockup Post Type Functions
 *
 * @package    project-huddle
 * @subpackage ph-image-approvals
 */

/**
 * Add new column
 *
 * @param $defaults
 *
 * @return mixed
 */
function pha_listing_columns_head( $defaults ) {
	$defaults['progress'] = __( 'Progress', 'project-huddle' );
	$defaults['approval'] = __( 'Status', 'project-huddle' );

	return $defaults;
}

add_filter( 'manage_ph-project_posts_columns', 'pha_listing_columns_head', 9 );

/**
 * Show column value
 *
 * @param $column_name
 * @param $post_ID
 */
function pha_listing_columns_content( $column_name, $post_ID ) {
	if ( $column_name == 'approval' ) {
		ph_approval_badge( $post_ID );
	}
	if ( $column_name == 'progress' ) {
		ph_approval_progress_bar( $post_ID );
	}
}

add_action( 'manage_ph-project_posts_custom_column', 'pha_listing_columns_content', 10, 2 );

if ( ! function_exists( 'ph_approval_progress_bar' ) ) :
	/**
	 * Displays a progress bar for the project
	 *
	 * @param int $id Project ID
	 *
	 * @return void
	 */
	function ph_approval_progress_bar( $id = 0 ) {
		global $post;
		if ( ! $id ) {
			$id = is_object( $post ) ? $post->ID : false;
		}
		if ( ! $id ) {
			return;
		}

		$total           = PH()->project->total_images( $id );
		if ( ! $total ) {
			return;
		}
		$approved        = PH_Approvals()->project->total_approved_images( $id );
		$percentage      = $total ? $approved / $total * 100 : 0;
		$approval_class  = $total && $approved >= $total ? 'approved' : 'unapproved';
		$progress_string = sprintf( __( '%1$s of %2$s images approved.', 'project-huddle' ),
			$approved,
			$total
		);
		echo '<div class="progress-wrap ' . $approval_class . '" data-tooltip="' . esc_attr( $progress_string ) . '">';
		echo '<div class="ph-approval-bar"><div class="ph-approval-amount" style="width: ' . $percentage . '%;"></div></div>';
		echo '</div>';
	}
endif;

if ( ! function_exists( 'ph_approval_badge' ) ) :
	/**
	 * Displays an approval badge for the project
	 *
	 * @param int $id Project ID
	 *
	 * @return void
	 */
	function ph_approval_badge( $id = 0 ) {
		global $post;
		if ( ! $id ) {
			$id = is_object( $post ) ? $post->ID : false;
		}
		if ( ! $id ) {
			return;
		}

		$approval = PH_Approvals()->project->approval( $id );

		if ( $approval && is_array( $approval ) && isset( $approval['approval'] ) ) {
			if ( $approval['approval'] ) {
				if ( isset( $approval['on'] ) ) {
					$date = date_create_from_format( "Y-m-d H:i:s", $approval['on'] );

					$date_string = sprintf( __( 'By %1$s on %2$s at %3$s', 'project-huddle' ),
						$approval['by']['display_name'],
						date_format( $date, get_option( 'date_format' ) ),
						date_format( $date, get_option( 'time_format' ) )
					);

					echo '<span class="approval-badge approved" data-tooltip="' . esc_attr( $date_string ) . '">' . __( 'Approved', 'project-huddle' ) . '</span>';
				} else {
					echo '<span class="approval-badge approved">' . __( 'Approved', 'project-huddle' ) . '</span>';
				}
			} else {
				echo '<span class="approval-badge">' . __( 'UnApproved', 'project-huddle' ) . '</span>';
			}
		} else {
			echo '<span class="approval-badge">' . __( 'UnApproved', 'project-huddle' ) . '</span>';
		}
	}
endif;