<?php
/**
 * General Addon Settings
 *
 * @package    project-huddle
 * @subpackage ph-image-approvals
 */

/**
 * Add approval settings to settings menu
 *
 * @param $settings
 *
 * @return mixed
 *
 * @since 1.1.1
 */
function ph_add_button_settings( $settings ) {
	$approve_settings = apply_filters( 'ph_approve_settings', array(
		array(
			'id'          => 'approval_button_divider',
			'label'       => __( 'Approvals', 'project-huddle' ),
			'description' => '',
			'type'        => 'divider',
		),
		array(
			'id'          => 'approve_color',
			'label'       => __( 'Approve Button Background Color', 'project-huddle' ),
			'description' => __( 'This is the background color for the "Approve" button.', 'project-huddle' ),
			'type'        => 'color',
			'default'     => '#7bae54'
		),
		array(
			'id'          => 'unapprove_color',
			'label'       => __( 'UnApprove Button Background Color', 'project-huddle' ),
			'description' => __( 'This is the background color for the "Approve" button.', 'project-huddle' ),
			'type'        => 'color',
			'default'     => '#6F7C8A'
		),
		array(
			'id'          => 'approve_text',
			'label'       => __( 'Approve Text', 'project-huddle' ),
			'description' => __( 'HTML Allowed. Use {{image_name}} to output the name of the image and {{project_name}} for the project.', 'project-huddle' ),
			'type'        => 'textarea',
			'default'     => sprintf( __( 'Are you sure you want to approve %s?', 'project-huddle' ), '<strong>{{image_name}}</strong>' )
		),
		array(
			'id'          => 'unapprove_text',
			'label'       => __( 'Un-Approve Text', 'project-huddle' ),
			'description' => __( 'HTML Allowed. Use {{image_name}} to output the name of the image and {{project_name}} for the project.', 'project-huddle' ),
			'type'        => 'textarea',
			'default'     => sprintf( __( 'Are you sure you want to unapprove %s?', 'project-huddle' ), '<strong>{{image_name}}</strong>' )
		),
		array(
			'id'          => 'approval_type',
			'label'       => __( 'Approval Type', 'project-huddle' ),
			'description' => __( 'Select whether approvals should approve the entire project or just the current image. You may need to change the approve text.', 'project-huddle' ),
			'type'        => 'radio',
			'options'     => array(
				'image'   => __( 'Approve the image only', 'project-huddle' ),
				'project' => __( 'Approve the entire project', 'project-huddle' )
			),
			'default'     => 'image'
		),
		array(
			'id'          => 'require_terms',
			'label'       => __( 'Approval Terms &amp; Conditions Checkbox', 'project-huddle' ),
			'description' => __( 'Option to require terms and conditions checkbox on approvals.', 'project-huddle' ),
			'type'        => 'radio',
			'options'     => array(
				0 => __( 'Don\'t require terms agreement', 'project-huddle' ),
				1 => __( 'Require terms agreement', 'project-huddle' )
			),
			'default'     => 0
		),
		array(
			'id'          => 'approve_terms_checkbox_text',
			'label'       => __( 'Approval Terms Checkbox Text', 'project-huddle' ),
			'description' => __( 'Approval Terms Checkbox Text. Use {{terms}} to place the terms link and {{user_name}} to display the current identified user.', 'project-huddle' ),
			'type'        => 'text',
			'default'     => sprintf( __( 'I, %2$s, read and agree with the %1$s.', 'project-huddle' ), '{{terms}}', '{{user_name}}' ),
			'required'    => array(
				'require_terms' => 1
			)
		),
		array(
			'id'          => 'approve_terms_link_text',
			'label'       => __( 'Approval Terms Link Text', 'project-huddle' ),
			'description' => __( 'Clickable text to show the terms.', 'project-huddle' ),
			'type'        => 'text',
			'default'     => __( 'Terms', 'project-huddle' ),
			'required'    => array(
				'require_terms' => 1
			)
		),
		array(
			'id'          => 'approve_terms',
			'label'       => __( 'Approval Terms', 'project-huddle' ),
			'description' => __( 'Full Terms and Conditions. HTML Allowed.', 'project-huddle' ),
			'type'        => 'textarea',
			'default'     => '',
			'required'    => array(
				'require_terms' => 1
			)
		),
	) );

	// add our fields
	$settings['fields'] = array_merge( $settings['fields'], $approve_settings );

	return $settings;
}

add_filter( 'ph_settings_mockups', 'ph_add_button_settings' );

function ph_approval_style_output() {?>
	<?php if ( $ph_highlight_color = get_option( 'ph_highlight_color') ) : ?>
	.project-huddle ul.image-filter-menu li.active {
		color: <?php echo apply_filters( 'ph_highlight_color_output', esc_attr( $ph_highlight_color ) ); ?>;
	}
	<?php endif; ?>

	<?php if ( $ph_image_tray_color = get_option( 'ph_image_tray_color') ) : ?>
	/* Image Tray Color */
	.projecthuddle #ph-thumbs-navigator .image-filter-dropdown {
		color: <?php echo apply_filters( 'ph_image_tray_color_output', esc_attr( $ph_image_tray_color ) ); ?>;
	}
	<?php endif; ?>
<?php
}
add_action('ph_style_options_output', 'ph_approval_style_output' );