<?php
/**
 * API Functions
 *
 * Process the API Requests
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       2.1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class PHA_Approval_Actions extends PH_Project_Actions_Abstract {
	/**
	 * Variable to store author
	 *
	 * @var object
	 */
	protected $user;

	/**
	 * Variable to store model data
	 */
	protected $data;

	/**
	 * Setup project admin
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_filter( 'ph_mockup_approve_image', array( $this, 'image_approval' ) );
		add_filter( 'ph_mockup_approve_project', array( $this, 'project_approval' ) );

		add_action( 'ph_after_mockup_image_approval', array( $this, 'add_email' ) );
		add_action( 'ph_after_mockup_project_approval', array( $this, 'add_email' ) );
	}

	/**
	 * Approve Image Only
	 *
	 * @param $data object Image Model
	 *
	 * @return mixed|WP_Error
	 */
	public function image_approval( $data ) {
		$this->data = $data->get_params();
		$this->user = wp_get_current_user();

		if ( ! isset( $this->data['approved'] ) ) {
			return new WP_Error( 'could_not_change_approval', __( 'Something went wrong with the approval. Please reload the page and try again.', 'project-huddle' ) );
		}

		PH_Approvals()->image->add_approval( $this->data['id'], array(
			'approval' => (boolean) $this->data['approved'],
			'by'       => array(
				'email'        => esc_attr( $this->user->user_email ),
				'display_name' => esc_attr( $this->user->display_name ),
				'wp_user'      => $this->user->ID ? $this->user->ID : false
			)
		) );

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		// backwards compat
		do_action('ph_after_mockup_set_approval', $this->data);
		$this->data = apply_filters('ph_after_mockup_set_approval', $this->data);

		return $this->data;
	}

	/**
	 * Approve Project (All Images)
	 *
	 * @param $data object Project Model
	 *
	 * @return mixed|WP_Error
	 */
	public function project_approval( $data ) {
		$this->data = $data->get_params();
		$this->user = wp_get_current_user();

		if ( ! isset( $this->data['approved'] ) ) {
			return new WP_Error( 'could_not_change_approval', __( 'Something went wrong with the approval. Please reload the page and try again.', 'project-huddle' ) );
		}

		$project_images = (array) get_post_meta( $this->data['id'], 'ph_project_images', true );

		foreach ($project_images as $image_id) {
			// find last approval
			$approval = (array) get_post_meta( (int) $image_id, 'ph_approved', true );

			// add latest approval to chain
			$approval[] = array(
				'approval' => (boolean) $this->data['approved'],
				'by'       => array(
					'email'        => esc_attr( $this->user->user_email ),
					'display_name' => esc_attr( $this->user->display_name ),
					'wp_user'      => $this->user ? $this->user : false
				),
				'on'       => date( "Y-m-d H:i:s" )
			);

			// store approval in post meta
			update_post_meta( (int) $image_id, 'ph_approved', $approval );
		}

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		return $this->data;
	}
}