<?php
/**
 * ProjectHuddle API Endpoints
 *
 * Creates rest routes, sanitizes and validates, adds filters to hook functions.
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2016, Andre Gagnon
 * @since       1.3.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * PH_Admin_Project_Images Class
 *
 * This class handles the all the ajax requests made by the plugin
 *
 * @since 1.0.0
 */
class PHA_Api extends PH_Project_API {

	public function __construct() {
		add_action( 'rest_api_init', array( $this, 'ph_approval_routes') );
		// call project API constructor
		parent::__construct();
	}

	public function ph_approval_routes() {
		$base = 'image';
		// POST new
		register_rest_route( $this->route_url, '/' . $base . '/(?P<id>\d+)/approve',
			array(
				'methods'  => array( 'PUT', 'PATCH' ),
				'callback' => function ( $data ) {
					return apply_filters( $this->prefix . 'mockup_approve_image', $data ); // make callback filterable
				},
				'args'     => array(
					'project_id' => array(
						'sanitize_callback' => 'absint', // only non-negative integers allowed
					),
				),
				'permission_callback' => function ($data) {
					return $this->check_identity($data);
				}
			)
		);

		// Approve project
		register_rest_route( $this->route_url, '/(?P<id>\d+)/approve',
			array(
				'methods'  => array( 'PUT', 'PATCH' ),
				'callback' => function ( $data ) {
					return apply_filters( $this->prefix . 'mockup_approve_project', $data ); // make callback filterable
				},
				'args'     => array(
					'project_id' => array(
						'sanitize_callback' => 'absint', // only non-negative integers allowed
					),
				),
				'permission_callback' => function ($data) {
					return $this->check_identity($data);
				}
			)
		);
	}
}
new PHA_Api();
