<?php
/**
 * Extend Image data to include approvals
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       2.3.0
 */
class PH_Image_Approval extends PH_Image {

	/**
	 * Variable to store our approval
	 * @var array
	 */
	public $approval;

	/**
	 * Change image approval
	 *
	 * @param integer $id
	 * @param array   $approval
	 *
	 * @return bool
	 */
	public function change_approval( $id, $approval = array() ) {
		if ( ! $id || empty( $approval ) ) return false;
		return update_post_meta( (int) $id, 'ph_approved', $approval );
	}

	/**
	 * Get image approval
	 *
	 * @param $id int ID of image
	 *
	 * @return array Approval Data
	 */
	public function get_approval( $id ) {
		return (array) get_post_meta( (int) $id, 'ph_approved', true );
	}

	/**
	 * Is the image approved
	 *
	 * @param $id
	 *
	 * @return mixed
	 */
	public function is_approved( $id ) {
		$approval = $this->last_approval( $id );

		return isset( $approval['approval'] ) ? $approval['approval'] : false;
	}

	/**
	 * Return the last approval status
	 *
	 * @param $id
	 *
	 * @return bool|mixed
	 */
	public function last_approval( $id ) {
		$approval = $this->get_approval( $id );
		// find last image approval
		if ( is_array( $approval ) ) {
			end( $approval );         // move the internal pointer to the end of the array
			$key = key( $approval );  // fetches the key of the element pointed to by the internal pointer
		}
		return isset( $key ) ? $approval[ $key ] : false;
	}

	/**
	 * Adds another approval to the chain
	 *
	 * @param integer $id           Image ID
	 * @param array   $approve_data Approval Data
	 *
	 * @return bool
	 */
	public function add_approval( $id, $approve_data = array() ) {
		if ( empty( $approve_data ) ) {
			return false;
		}

		// get approvals
		$approval = $this->get_approval( $id );

		// store date
		$approve_data['on'] = date( "Y-m-d H:i:s" );

		// add latest approval to chain
		$approval[] = $approve_data;

		// store approval
		return $this->change_approval( $id, $approval );
	}
}