<?php
/**
 * Email Functions
 */

/**
 * Email project approval notification to everyone on the project
 *
 * @param $data
 *
 * @since    1.1.1
 */
function ph_email_image_approved( $data ) {
	$user       = $data['user'];
	$model      = $data;
	$image_id   = $data['image_id'];
	$project_id = $data['project_id'];

	// is project is approved, do that instead
	if ( PH_Approvals()->project->is_approved( $project_id ) ) {
		ph_email_project_approved( $data );
		return;
	}

	$current_user = wp_get_current_user();

	$to_emails = (array) apply_filters( 'ph_mockup_approved_image_to', ph_get_project_emails( $project_id, $user ), $model, $current_user );

	// send each email individually
	foreach ( $to_emails as $email ) {
		if ( $model['approved'] ) {
			$email = ( new PH_Mail )
				->template( ph_locate_template( 'email/approved-image-email.php', '', PH_APPROVALS_PLUGIN_DIR . 'templates/' ), [
					'commenter'    => sanitize_text_field( $current_user->display_name ),
					'avatar'       => get_avatar( $current_user->ID, 42, '', '', array(
						'force_display' => true,
						'extra_attr'    => 'style="border-radius: 42px"'
					) ),
					'image_name'   => sanitize_text_field( html_entity_decode( $model['title'] ) ),
					'project_name' => sanitize_text_field( html_entity_decode( get_the_title( $project_id ) ) ),
					'link'         => ph_email_link( esc_url( get_permalink( $project_id ) . '#' . esc_attr( get_post( $image_id )->post_name ) ), __( 'View Image', 'project-huddle' ) )
				] )
				->subject( get_option( 'ph_mockup_approved_image_subject', '{{commenter}} approved an image in {{project_name}}.' ) )
				->to( $email )
				->send();
		} else {
			$email = ( new PH_Mail )
				->template( ph_locate_template( 'email/unapproved-image-email.php', '', PH_APPROVALS_PLUGIN_DIR . 'templates/' ), [
					'commenter'    => sanitize_text_field( $current_user->display_name ),
					'avatar'       => get_avatar( $current_user->ID, 42, '', '', array(
						'force_display' => true,
						'extra_attr'    => 'style="border-radius: 42px"'
					) ),
					'image_name'   => sanitize_text_field( html_entity_decode( $model['title'] ) ),
					'project_name' => sanitize_text_field( html_entity_decode( get_the_title( $project_id ) ) ),
					'link'         => ph_email_link( esc_url( get_permalink( $project_id ) . '#' . esc_attr( get_post( $image_id )->post_name ) ), __( 'View Image', 'project-huddle' ) )
				] )
				->subject( get_option( 'ph_mockup_unapproved_image_subject', '{{commenter}} unapproved an image in {{project_name}}.' ) )
				->to( $email )
				->send();
		}
	}
}
add_action( 'ph_after_mockup_image_approval', 'ph_email_image_approved', 20 );

/**
 * Email project approval notification to everyone on the project
 *
 * @param array $data model data
 *
 * @since    2.2.0
 */
function ph_email_project_approved(  $data ) {
	$user       = $data['user'];
	$model      = $data;
	$project_id = $data['project_id'];

	// get all emails
	if ( ! $to_emails = ph_get_project_emails( $project_id, $user ) ) {
		return;
	}

	$current_user = wp_get_current_user();

	// get emails
	$to_emails = (array) apply_filters( 'ph_mockup_approved_project_to', ph_get_project_emails( $project_id, $user ), $model, $current_user );

	// send each email individually
	foreach ( $to_emails as $email ) {
		// create correct string
		if ( $model['approved'] ) {
			$email = ( new PH_Mail )
				->template( ph_locate_template( 'email/approved-project-email.php', '', PH_APPROVALS_PLUGIN_DIR . 'templates/' ), [
					'commenter'    => sanitize_text_field( $current_user->display_name ),
					'avatar'       => get_avatar( $current_user->ID, 42, '', '', array(
						'force_display' => true,
						'extra_attr'    => 'style="border-radius: 42px"'
					) ),
					'project_name' => sanitize_text_field( get_the_title( $project_id ) ),
					'link'         => ph_email_link( esc_url( get_permalink( $project_id ) ), __( 'View Project', 'project-huddle' ) )
				] )
				->subject( get_option( 'ph_mockup_approved_project_subject', '{{commenter}} approved {{project_name}}.' ) )
				->to( $to_emails )
				->send();
		} else {
			$email = ( new PH_Mail )
				->template( ph_locate_template( 'email/unapproved-project-email.php', '', PH_APPROVALS_PLUGIN_DIR . 'templates/' ), [
					'commenter'    => sanitize_text_field( $current_user->display_name ),
					'avatar'       => get_avatar( $current_user->ID, 42, '', '', array(
						'force_display' => true,
						'extra_attr'    => 'style="border-radius: 42px"'
					) ),
					'project_name' => sanitize_text_field( get_the_title( $project_id ) ),
					'link'         => ph_email_link( esc_url( get_permalink( $project_id ) ), __( 'View Project', 'project-huddle' ) )
				] )
				->subject( get_option( 'ph_mockup_unapproved_project_subject', '{{commenter}} unapproved {{project_name}}.' ) )
				->to( $to_emails )
				->send();
		}
	}
}
add_action( 'ph_after_mockup_project_approval', 'ph_email_project_approved', 20 );