<?php
/**
 * Approval Functions
 *
 * Misc functions used througout the plugin
 *
 * @package     PH Image Versions
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.1.1
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Function to get approvals meta
 * So we only need to edit in one place
 *
 * @param $image_id bool ID of image
 *
 * @return array
 */
function ph_get_approvals( $image_id ) {
    return get_post_meta( $image_id, 'ph_approved', true );
}

/**
 * Get last approval data
 *
 * @param int $image_id
 *
 * @return array|bool Last approval array
 */
function ph_last_approval_data( $image_id = 0 ) {
    if ( ! $image_id ) {
        return false;
    }

    // get approvals
    $approval = ph_get_approvals( $image_id );

    // find last
    if ( is_array( $approval ) ) {
        $approvals = get_post_meta( $image_id, 'ph_approved', true );
        end( $approvals );         // move the internal pointer to the end of the array
        $key = key( $approvals );  // fetches the key of the element pointed to by the internal pointer
    }

    // return last approval array or string
    return isset( $key ) && isset( $approvals[ $key ] ) ? $approvals[ $key ] : $approval;
}

/**
 * Gets the latest approval boolean from the approval array
 *
 * @param int $image_id Image ID
 *
 * @return bool Approved or not
 *
 * @access public
 * @since  1.1.1
 */
function ph_get_latest_approval( $image_id ) {
    $approval = ph_last_approval_data( $image_id );
    // get latest approval
    if ( is_array( $approval ) && ! empty( $approval ) && isset( $approval['approval'] ) ) {
        return $approval['approval'];
    } else {
        return $approval;
    }
}

/**
 * Get last approval without setting anything
 *
 * @param int  $image_id ID of image
 *
 * @return bool/array
 */
function ph_last_approval( $image_id ) {
    $last_approval = ph_get_latest_approval( $image_id );

    return $last_approval;
}




/**
 * Permissions
 */
function ph_approval_permissions( $data ) {
    global $post;

    // add our approval options for js
    $data['options']['project']['allow_approve']   = get_post_meta( $post->ID, 'ph_project_approval', true );
    $data['options']['project']['allow_unapprove'] = get_post_meta( $post->ID, 'ph_project_unapproval', true );

    return $data;
}
add_filter( 'ph_project_data', 'ph_approval_permissions' );