<?php
/**
 * Gets latest approval from meta data
 *
 * @param array $image
 * @param int   $image_id
 *
 * @return mixed
 * @access public
 * @since  1.1.1
 */
function ph_approval_data( $image, $image_id ){
	// get straight up boolean on last approval
	$last_approval = ph_get_latest_approval( $image_id );

	$image['approved'] = (boolean) $last_approval;

	return $image;
}
add_action( 'ph_image_data', 'ph_approval_data', 11, 2 );


/**
 * Add global terms option to project options
 *
 * @param $options
 *
 * @return mixed
 */
function ph_add_approve_options( $options ) {
	$options['require_terms'] = get_option( 'ph_require_terms' );
	$options['approval_type'] = get_option( 'ph_approval_type' );

	return $options;
}

add_filter( 'ph_global_project_options', 'ph_add_approve_options' );

/**
 * Add custom approve text to project data
 *
 * @param $translations
 *
 * @return mixed|void
 */
function ph_add_approval_text_options($translations) {
	global $post;

	// approve/unapprove text
	if ( $approve_text = get_option( 'ph_approve_text' ) ) {
		$translations['confirmApprove'] = wp_kses_post( $approve_text );
	}
	if ( $unapprove_text = get_option( 'ph_unapprove_text' ) ) {
		$translations['confirmUnApprove'] = wp_kses_post( $unapprove_text );
	}

	// checkbox/terms
	if ( $checkbox_text = get_option( 'ph_approve_terms_checkbox_text' ) ) {
		$translations['approveCheckbox'] = esc_html( $checkbox_text );
	}
	if ( $checkbox_link = get_option( 'ph_approve_terms_link_text' ) ) {
		$translations['approveCheckboxLink'] = esc_html( $checkbox_link );
	}
	if ( $terms = get_option( 'ph_approve_terms' ) ) {
		$translations['approveTerms'] = wp_kses_post( $terms );
	}

	// return translations and filter in case we need to change on a per-post basis
	return apply_filters( 'ph_approval_text', $translations, $post );
}