<?php
/**
 * Approval Scripts
 *
 * Scripts and stylesheets used for approval
 *
 * @package     PH Image Versions
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Approval Scripts
 *
 * Scripts strictly for approvals
 *
 * @access public
 * @since  1.1.0
 */
function pha_project_scripts() {
	// get post type
	global $post_type;

	// bail out early if we are not on a project add/edit screen.
	if ( 'ph-project' != $post_type ) {
		return false;
	}

	// store javascript directory
	$js_dir = PH_APPROVALS_PLUGIN_URL . 'assets/js/';

	// store javascript directory
	$css_dir = PH_APPROVALS_PLUGIN_URL . 'assets/css/';

	// add versions script
	wp_enqueue_script( 'ph-approvals-script', $js_dir . 'ph-approvals.js', array(
		'jquery',
		'backbone',
		'underscore',
		'wp-backbone',
		'project-huddle'
	), PH_VERSION, false );

	// add stylesheet
	wp_enqueue_style( 'ph-approvals-style', $css_dir . 'ph-image-approvals.css', array(), PH_VERSION );

	// localize nonce and admin ajax
	wp_localize_script( 'ph-approvals-script', 'phApproval', array(
		'ajaxurl' => esc_url( admin_url( 'admin-ajax.php' ) ),
		'phNonce' => wp_create_nonce( 'ph-approval-nonce' )
	));
}
add_action( 'wp_enqueue_scripts', 'pha_project_scripts' );

function ph_approval_admin_scripts( $hook ) {
	// get post type
	global $post_type;

	// bail out early if we are not on a project add/edit screen.
	if ( 'ph-project' != $post_type  ) {
		return false;
	}

	$css_dir = PH_APPROVALS_PLUGIN_URL . 'assets/css/';

	// Use minified libraries if SCRIPT_DEBUG is turned off
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	// enqueue main style
	wp_enqueue_style( 'project-huddle-approvals-css', $css_dir . 'ph-approvals-admin' . $suffix . '.css', array(), PH_VERSION );
}
add_action( 'admin_enqueue_scripts', 'ph_approval_admin_scripts' );

/**
 * Add our approvals script handle to list of allowed scripts
 *
 * @param array $scripts Scripts to include
 *
 * @return array With our added script
 *
 * @access public
 * @since  1.1.0
 */
function ph_approvals_script_handles( $scripts = array() ){
	$scripts[] = 'ph-approvals-script';

	return $scripts;
}
add_filter( 'ph_allowed_scripts', 'ph_approvals_script_handles' );

/**
 * Add our approvals script handle to list of allowed scripts
 *
 * @param array $styles Scripts to include
 *
 * @return array With our added script
 *
 * @access public
 * @since  1.1.0
 */
function ph_approvals_style_handles( $styles = array() ){
	$styles[] = 'ph-approvals-style';

	return $styles;
}
add_filter( 'ph_allowed_styles', 'ph_approvals_style_handles' );