<?php
/*
 * Extend PH Shortcodes to add approval display/options
 */

/**
 * Add additional default parameters to shortcode
 *
 * @param $atts
 *
 * @return mixed
 */
function ph_shortcode_approvals( $out, $pairs, $atts, $shortcode ) {
	$pairs['show_approvals']   = true;
	$pairs['show_unapprovals'] = true;
	$pairs['approved_by']      = false;

	// extend defaults with user $atts
	$out = wp_parse_args( $atts, $pairs );

	return $out;
}

add_filter( 'shortcode_atts_ph_subscribed_projects', 'ph_shortcode_approvals', 10, 4 );
add_filter( 'shortcode_atts_project_huddle', 'ph_shortcode_approvals', 10, 4 );


/**
 * Add approved/unapproved to shortcode title
 *
 * @param $atts  array Shortcode attributes
 * @param $image array Image attributes
 *
 * @return string
 */
function ph_approval_shortcode_title( $atts, $image ) {
	$approved = ph_last_approval_data( $image['ID'] );

	$output   = '';

	// add new line if titles are turned on
	if ( $atts['titles'] ) {
		$output = '<br>';
	}

	// add approval output if turned on
	if ( $atts['show_approvals'] ) {
		if ( isset( $approved['approval'] ) && $approved['approval'] ) {
			$output .= '<small class="ph-approved">';
			$output .= '<span style="color:' . get_option( 'ph_approve_color', '#7bae54' ) . '; ">';
			$output .= __( 'Approved', 'project-huddle' );
			$output .= '</span>';
			if ( $atts['approved_by'] ) {
				$output .= ' ' . sprintf( __('by %s', 'project-huddle'), $approved['by']['display_name']);
			}
			$output .= '</small>';
		}
	}
	if ( $atts['show_unapprovals'] ) {
		if ( isset( $approved['approval'] ) && ! $approved['approval'] ) {
			$output .= '<small class="ph-unapproved" style="color:' . get_option( 'ph_unapprove_color', '#6F7C8A' ) . '; ">';
			$output .= __( 'Unapproved', 'project-huddle' );
			$output .= '</small>';
		}
	}

	return $output;
}

add_filter( 'shortcode_title_project_huddle', 'ph_approval_shortcode_title', 10, 3 );

/**
 * Show/Hide approval title
 *
 * @param $show_title
 * @param $atts
 *
 * @return bool
 */
function ph_show_approval_title( $show_title, $atts ) {
	if ( isset( $atts['show_approvals'] ) && isset( $atts['show_unapprovals'] ) ) {
		if ( $atts['show_approvals'] || $atts['show_unapprovals'] ) {
			return true;
		}
	}

	return $show_title;
}

add_filter( 'shortcode_show_title_project_huddle', 'ph_show_approval_title', 10, 2 );


/**
 * Add approved/unapproved to project titles in shortcode
 *
 * @param $title string Current project title
 * @param $id    int Project ID
 * @param $atts  array Shortcode attributes
 *
 * @return string Filtered project title
 */
function ph_subscribed_shortcode_project_list_title( $title, $id, $atts ) {

	// find if all are approved
	$all_approved = PH_Approvals()->project->is_approved( $id );

	// approvals/unapprovals
	if ( $atts['show_approvals'] ) {
		if ( $all_approved ) {
			return $title . ' <small class="ph-approved" style="color:' . get_option( 'ph_approve_color', '#7bae54' ) . '; ">' . __( 'Approved', 'project-huddle' ) . '</small>';
		}
	}
	if ( $atts['show_unapprovals'] ) {
		if ( ! $all_approved ) {
			return $title . ' <small class="ph-unapproved" style="color:' . get_option( 'ph_unapprove_color', '#6F7C8A' ) . '; ">' . __( 'Unapproved', 'project-huddle' ) . '</small>';
		}
	}

	return $title;
}

add_filter( 'ph_subscribed_project_list_title', 'ph_subscribed_shortcode_project_list_title', 10, 3 );