/**
 * Javascript functions for versions
 *
 * @since 1.0
 */

// strict mode
'use strict';

(function() {

	Date.shortMonths = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
	Date.longMonths = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
	Date.shortDays = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];
	Date.longDays = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];

	// defining patterns
	var replaceChars = {
		// Day
		d: function() { return (this.getDate() < 10 ? '0' : '') + this.getDate(); },
		D: function() { return Date.shortDays[this.getDay()]; },
		j: function() { return this.getDate(); },
		l: function() { return Date.longDays[this.getDay()]; },
		N: function() { return (this.getDay() == 0 ? 7 : this.getDay()); },
		S: function() { return (this.getDate() % 10 == 1 && this.getDate() != 11 ? 'st' : (this.getDate() % 10 == 2 && this.getDate() != 12 ? 'nd' : (this.getDate() % 10 == 3 && this.getDate() != 13 ? 'rd' : 'th'))); },
		w: function() { return this.getDay(); },
		z: function() { var d = new Date(this.getFullYear(),0,1); return Math.ceil((this - d) / 86400000); }, // Fixed now
		// Week
		W: function() {
			var target = new Date(this.valueOf());
			var dayNr = (this.getDay() + 6) % 7;
			target.setDate(target.getDate() - dayNr + 3);
			var firstThursday = target.valueOf();
			target.setMonth(0, 1);
			if (target.getDay() !== 4) {
				target.setMonth(0, 1 + ((4 - target.getDay()) + 7) % 7);
			}
			return 1 + Math.ceil((firstThursday - target) / 604800000);
		},
		// Month
		F: function() { return Date.longMonths[this.getMonth()]; },
		m: function() { return (this.getMonth() < 9 ? '0' : '') + (this.getMonth() + 1); },
		M: function() { return Date.shortMonths[this.getMonth()]; },
		n: function() { return this.getMonth() + 1; },
		t: function() {
			var year = this.getFullYear(), nextMonth = this.getMonth() + 1;
			if (nextMonth === 12) {
				year = year++;
				nextMonth = 0;
			}
			return new Date(year, nextMonth, 0).getDate();
		},
		// Year
		L: function() { var year = this.getFullYear(); return (year % 400 == 0 || (year % 100 != 0 && year % 4 == 0)); },   // Fixed now
		o: function() { var d  = new Date(this.valueOf());  d.setDate(d.getDate() - ((this.getDay() + 6) % 7) + 3); return d.getFullYear();}, //Fixed now
		Y: function() { return this.getFullYear(); },
		y: function() { return ('' + this.getFullYear()).substr(2); },
		// Time
		a: function() { return this.getHours() < 12 ? 'am' : 'pm'; },
		A: function() { return this.getHours() < 12 ? 'AM' : 'PM'; },
		B: function() { return Math.floor((((this.getUTCHours() + 1) % 24) + this.getUTCMinutes() / 60 + this.getUTCSeconds() / 3600) * 1000 / 24); }, // Fixed now
		g: function() { return this.getHours() % 12 || 12; },
		G: function() { return this.getHours(); },
		h: function() { return ((this.getHours() % 12 || 12) < 10 ? '0' : '') + (this.getHours() % 12 || 12); },
		H: function() { return (this.getHours() < 10 ? '0' : '') + this.getHours(); },
		i: function() { return (this.getMinutes() < 10 ? '0' : '') + this.getMinutes(); },
		s: function() { return (this.getSeconds() < 10 ? '0' : '') + this.getSeconds(); },
		u: function() { var m = this.getMilliseconds(); return (m < 10 ? '00' : (m < 100 ?
						'0' : '')) + m; },
		// Timezone
		e: function() { return /\((.*)\)/.exec(new Date().toString())[1]; },
		I: function() {
			var DST = null;
			for (var i = 0; i < 12; ++i) {
				var d = new Date(this.getFullYear(), i, 1);
				var offset = d.getTimezoneOffset();

				if (DST === null) DST = offset;
				else if (offset < DST) { DST = offset; break; }                     else if (offset > DST) break;
			}
			return (this.getTimezoneOffset() == DST) | 0;
		},
		O: function() { return (-this.getTimezoneOffset() < 0 ? '-' : '+') + (Math.abs(this.getTimezoneOffset() / 60) < 10 ? '0' : '') + (Math.abs(this.getTimezoneOffset() / 60)) + '00'; },
		P: function() { return (-this.getTimezoneOffset() < 0 ? '-' : '+') + (Math.abs(this.getTimezoneOffset() / 60) < 10 ? '0' : '') + (Math.abs(this.getTimezoneOffset() / 60)) + ':00'; }, // Fixed now
		T: function() { return this.toTimeString().replace(/^.+ \(?([^\)]+)\)?$/, '$1'); },
		Z: function() { return -this.getTimezoneOffset() * 60; },
		// Full Date/Time
		c: function() { return this.format("Y-m-d\\TH:i:sP"); }, // Fixed now
		r: function() { return this.toString(); },
		U: function() { return this.getTime() / 1000; }
	};

	// Simulates PHP's date function
	Date.prototype.format = function(format) {
		var date = this;
		return format.replace(/(\\?)(.)/g, function(_, esc, chr) {
			return (esc === '' && replaceChars[chr]) ? replaceChars[chr].call(date) : chr;
		});
	};

}).call(this);

window.wp = window.wp || {};
window.Huddle = window.Huddle || {};
window.phV = window.phV || {};

/**
 * Filter trash confirm text
 */
wp.hooks.addFilter( 'huddle.trashConfirm', function ( text ) {
	text += "\n\n" + phVersion.translations.confirmTrash;

	return text;
});
/**
 * Mixins used in the app. Used to sync admin-ajax.php with backbone
 *
 * @package     ProjectHuddle
 * @subpackage  js
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

/**
 * A mixin for collections/models that syncs with admin-ajax.php
 *
 * @since 1.0.0
 */
var phVersionsAdminAjaxMixin = {

	// admin-ajax.php url
	url:  phVersion.ajaxurl,

	// sync function
	sync: function (method, object, options) {

		// check if data is provided
		if (typeof options.data === 'undefined') {
			options.data = {};
		}

		// send nonce and method
		options.data.nonce = phVersion.phNonce;
		options.data.action_type = method;

		// send current project ID
		options.data.project_id = Huddle.projectID ? Huddle.projectID : false;

		// send current user info
		options.data.user = Huddle.user ? {
			'email': Huddle.user.attributes.user_email,
			'display_name': Huddle.user.attributes.display_name
		} : false;

		// set default action if nothing is set
		if (typeof options.data.action === 'undefined') {
			options.data.action = 'no_action_defined';
		}

		/**
		 * Convert model or collection to json
		 */
		var json = this.toJSON();
		var formattedJSON = {};

		/**
		 * If the json is an array, it's a collection
		 * Otherwise, its a model
		 */
		if (json instanceof Array) {
			formattedJSON.models = json;
		} else {
			formattedJSON.model = json;
		}

		/**
		 * Extend the options.data object with the formatted json
		 */
		_.extend(options.data, formattedJSON);

		/**
		 * Prevent needing to json decode in php and use $_POST instead
		 */
		options.emulateJSON = true;

		/**
		 * Call Backbone sync method
		 */
		return Backbone.sync.call(this, 'create', object, options);
	}
};

/**
 * A model for all the syncable models to extend
 *
 * Adds toast errors if they exist
 *
 * @since 1.0.0
 */
var VersionsModel = Backbone.Model.extend( _.defaults( {
	/**
	 * Extend constructor
	 */
	constructor: function() {
		Backbone.Model.apply(this, arguments);
	},

	/**
	 * Show errors if there are any
	 *
	 * @param response {object} Ajax response
	 */
	parse: function ( response ) {
		// Show our errors
		if ( response.success == false ) {

			// log error
			console.error( response );

			// trigger WordPress error if it exists
			if ( typeof response.data == 'string' ) {
				alert( response.data );
			}
			return false;

		} else {
			return response;
		}
	},

	/**
	 * Makes for easier ajax functions and triggers
	 *
	 * @param model             {object}    Model to run function
	 * @param callback          {function}  Function to run
	 * @param trigger           {string}    Event to trigger on Success
	 * @param failObjectTrigger {string}    Event to trigger if failure is object
	 */
	doAction: function( model, callback, trigger, failObjectTrigger ) {
		model[callback]( undefined, {
			success: function ( model, response, options ) {
				// handle success
				if ( response.success != false ) {
					model.trigger( trigger, model );
					// global event too
					Huddle.Event && Huddle.Event.trigger(  trigger, model  );
				} else {
					// if response is new object
					if ( typeof response.data == 'object' ) {
						failObjectTrigger && model.trigger( failObjectTrigger, response.data );
					}
				}
			},
			error: function ( model, xhr, options ) {
				console.error( xhr ); // don't output error for user
				alert( 'Something went wrong. Please try again.' );
			}
		} );
	}
}, phVersionsAdminAjaxMixin ) );

/**
 * A collection for all the syncable collections to extend
 *
 * @since 1.0.0
 */
var VersionsCollection = Backbone.Collection.extend( _.defaults( {
	/**
	 * Show errors if there are any
	 *
	 * @param response {object} Ajax response
	 */
	parse: function ( response ) {
		// Show our errors
		if ( response.success == false ) {

			// log error
			console.error( response );

			// trigger WordPress error if it exists
			if ( typeof response.data == 'string' ) {
				alert( response.data );
			}

			return false;

		} else {
			// trigger WordPress error if it exists
			return response;
		}
	},

	/**
	 * Makes for easier ajax functions and triggers
	 *
	 * @param model             {object}    Model to run function
	 * @param callback          {function}  Function to run
	 * @param trigger           {string}    Event to trigger on Success
	 * @param failObjectTrigger {string}    Event to trigger if failure is object
	 */
	doAction: function( model, callback, trigger, failObjectTrigger ) {
		model[callback]( undefined, {
			success: function ( model, response, options ) {
				// handle success
				if ( response.success != false ) {
					model.trigger( trigger, model );

					// global event too
					Huddle.Event && Huddle.Event.trigger(  trigger, model  );
				} else {
					// if response is new object
					if ( typeof response.data == 'object' ) {
						failObjectTrigger && model.trigger( failObjectTrigger, response.data );
					}
				}
			},
			error: function ( model, xhr, options ) {
				console.error( xhr ); // don't output error for user
				alert( 'Something went wrong. Please try again.' );
			}
		} );
	}
}, phVersionsAdminAjaxMixin ) );

/**
 * A view for all wp views to extend
 *
 * Extends wp.Backbone.View with .prepare() and .inject()
 *
 * @since 1.0.0
 */
Huddle.VersionsView = wp.Backbone.View.extend({
	inject: function( selector ) {
		this.render();
		jQuery(selector).html( this.el );
		this.views.ready();
	},
	injectTo: function( selector ) {
		this.render();
		jQuery(selector).append( this.el );
		this.views.ready();
	},
	prepare: function() {
		if ( ! _.isUndefined( this.model ) && _.isFunction( this.model.toJSON ) ) {
			this._parseTriggers();
			return this.model.toJSON();
		} else {
			return {};
		}
	},

	_parseTriggers: function () {
		if ( this.triggers ) {
			_.each( this.triggers || {}, function ( fn, event ) {
				var handler = this[fn];
				if ( _.isFunction( handler ) ) {
					this.stopListening( this.model, event, handler );
					this.listenTo( this.model, event, handler );
				}
			}, this );
		}
	}
});
/**
 * Extend defaults with our own
 */
_.extend( Huddle.Image.prototype.defaults, {
	version: 1,
	createDate: false,
	createTime: false,
	isoDate: false,
	currentVersion: false
});

/**
 * Hook into ImageView initialize model
 */
wp.hooks.addAction('Huddle.Image.initialize', function( model ){
	model.phvInitialize();
});

/**
 * Extending the image model prototype
 */
_.extend( Huddle.Image.prototype, {

	phvTime: false,

	phvInitialize: function() {

		// set default time to now
		this.phvTime = new Date();

		// set isodate if not set
		if ( ! this.attributes.isoDate ) {
			this.set('isoDate', this.phvTime.toISOString() );
		}

		// set create time if not set
		if ( ! this.attributes.createTime ) {
			this.set('createTime', this.phvTime.format('g:i a') );
		}

		// set create date if not set
		if ( ! this.attributes.createDate && Huddle.options.date_format ) {
			this.set('createDate', this.phvTime.format( Huddle.options.date_format ) );
		}

		// add our versions model in the image model
		this.versions = new Huddle.VersionsCollectionModel({
			collection: new Huddle.ImageVersionsCollection(
					this.versions ? this.versions.models : []
			),
			originalID: this.attributes.ID
		});
	},

    /**
     * Get options from settings
     */
    initialize: function () {
        // broadcast init
        wp.hooks.doAction('Huddle.Image.initialize', this);
    }
});
/**
 * Model to store our individual parent comments with location
 *
 * @extends VersionsModel Sync, save, fetch, update functions with app-ajax
 *
 * @since 1.0
 */
Huddle.VersionsCollectionModel = BaseModel.extend({

	defaults: {
		collection: false,
		originalID: false,
		current: false,
		fetched: false
	},

	initialize: function() {
		// when model is added, check if should be current
		this.listenTo( this.attributes.collection, 'add', this.setCurrent );
		this.listenTo( this.attributes.collection, 'restoreImage', this.setPointer );
		this.listenTo( this.attributes.collection, 'restoreImage', this.bubbleRestore );
	},

	/**
	 * When image is restored, set current pointer
	 *
	 * @param model
	 */
	setPointer: function( model ) {
		this.set( 'current', model.id );
		this.setCurrent( model );
	},

	/**
	 * Manually bubble up restore event
	 * @param model
	 */
	bubbleRestore: function( model ) {
		this.trigger( 'restoreImage', model );
	},

	/**
	 * Set correct model to current version
	 * @param model
	 */
	setCurrent: function( model ){
		// remove current from all models
		this.clearCurrent();

		// if no current item is set, set to last in collection
		if ( ! this.attributes.current ) {
			var lastModel = this.attributes.collection.last();
			lastModel.set( 'currentVersion', true );

			return;
		}

		if ( this.attributes.current == model.id ) {
			// set in added model
			model.set( 'currentVersion', true );
		}
	},

	/**
	 * Clears current attribute in all models
	 * @param model
	 */
	clearCurrent: function() {
		_.each( this.attributes.collection.models, function( image ) {
			image.set( 'currentVersion', false );
		}, this);
	}
});
/**
 * Collection to store all the images for this post
 *
 * @extends BaseCollection Sync, save, fetch, update functions with app-ajax
 *
 * @since 1.0
 */
Huddle.ImageVersionsCollection = BaseCollection.extend( {
	// Use image model for this collection
	model: Huddle.Image,

	initialize: function () {
		this.listenTo( this, 'add', this.setVersionNumbers );
		this.listenTo( this, 'updateVersions', this.setVersionNumbers );
	},

	/**
	 * Sort by date
	 * @param m Model
	 * @returns {number} Milliseconds since creation
	 */
	comparator: function (m) {
		return +new Date(m.get('isoDate'));
	},

	/**
	 * Update the order attribute for all comments
	 *
	 * @param model {object} Model
	 * @param options {object} Options
	 * @param silent {bool} Set silently or not
	 */
	setVersionNumbers: function ( model, options, silent ) {
		_.each( this.models, function( image ) {
			image.set( {
				version: this.indexOf( image ) + 1
			}, {
				silent: typeof silent == 'boolean' && silent ? silent : false
			} );
		}, this );
	},

	/**
	 *
	 * @param model
	 */
	setCurrent: function( model ){
		// remove current from all models
		this.clearCurrent();

		// set in added model
		var current = this.get(model);
		current.set( 'currentVersion', true );
	},

	/**
	 * Clears current attribute in all models
	 * @param model
	 */
	clearCurrent: function() {
		_.each( this.models, function( image ) {
			image.set( 'currentVersion', false );
		}, this);
	}
});
/**
 * Hook into ImageView initialize method
 */
wp.hooks.addAction('Huddle.ImageView.initialize', function( view ){
	view.phvInitialize();
});

// cache original events
var events = Huddle.ImageView.prototype.events;

/**
 * Extend the original image view
 * Adds new events, subviews and methods for ph versions
 */
_.extend( Huddle.ImageView.prototype, {

	// Add new events
	events: function () {
		return _.extend({}, events, {
			'click .ph-show-version': 'versionClick',
			'click .ph-new-version': 'newVersionClick'
		});
   },

	phvInitialize: function () {

		// listen for change to model and render
		this.listenTo( this.model, 'change', this.render );

		// when restoreImage event, swap out model in this view
		this.listenTo( this.model.versions, 'restoreImage', this.phvRestoreMerge );

		// add our menu items
		this.phvMenuItems();

		// bind this
		_.bindAll( this, 'selectNewVersion', 'addNewVersion' );
	},

	phvMenuItems: function() {
		// only add if model has been saved
		if ( this.model.attributes.ID == this.model.attributes.imageID ) {
			return;
		}

		// show versions
		this.views.add( '.ph-settings-menu', new Huddle.ShowVersionMenuItemView({
			model: this.model
		}), {
			at: 0
		});

		// new versions
		this.views.add( '.ph-settings-menu', new Huddle.NewVersionMenuItemView({
			model: this.model
		}), {
			at: 0
		});

	},

	/**
	 * Extend new model attributes
	 * @param model
	 */
	phvRestoreMerge: function( model ) {
		this.model.set( _.extend( {}, this.model.attributes, model.attributes ) );
	},

	/**
	 * Versions click handler
	 *
	 * @param e Click event
	 */
	versionClick: function( e ) {
		// prevent default action
		e.preventDefault();

		// create new versions modal view
		this.versionsModal = new Huddle.VersionsModal( {
			model: this.model
		} );

		// render versions modal view
		this.versionsModal.injectTo( 'body' );
	},

	/**
	 * New version click handler
	 *
	 * @param e Click Event
	 */
	newVersionClick: function( e ) {
		// prevent default action
		e.preventDefault();

		// open file frame
		this.phvOpenFileFrame( e );
	},

	/**
	 * Creates or Opens Existing File Frame
	 * @param e
	 */
	phvOpenFileFrame: function( e ) {
		// If the media frame already exists, reopen it.
		if ( this.version_file ) {
			this.version_file.open();
			return;
		}

		// Create the media frame
		this.version_file = wp.media( {
			title: jQuery( e.target ).data( 'uploader-title' ),
			button: {
				text: jQuery( e.target ).data( 'uploader-button-text' )
			},
			multiple: false  // Set to true to allow multiple files to be selected
		} );

		this.version_file.on( 'select', this.selectNewVersion );

		// Finally, open the modal
		this.version_file.open();
	},

	/**
	 * Gets and maps selection
	 */
	selectNewVersion: function() {
		// When an image is selected, run a callback.
		var selection = this.version_file.state().get( 'selection' );

		if ( selection.length ) {
			selection.map( this.addNewVersion );
			// Restore the main post ID
			wp.media.model.settings.post.id = this.wp_media_post_id;
		}
	},

	/**
	 * Handles selection mapping
	 * @param attachment selection
	 */
	addNewVersion: function( attachment ) {
		var imageURL = false;
		if ( typeof attachment.get('sizes').large == 'undefined' ) {
			imageURL = attachment.get('sizes').full.url
		} else {
			imageURL = attachment.get('sizes').large.url
		}

		// create new image
		var image = new Huddle.Image({
			id: attachment.get('id'),
			ID: attachment.get('id'),
            thumbnail: imageURL,
            url: attachment.get('sizes').full.url,
			imageID: attachment.get('id'),
			title: attachment.get('title'),
			parent: this.model.versions.get('originalID')
		});

		// get last version in collection
		var lastVersion = this.model.versions.get('collection').last();

        // options should stay the same as previous image
        image.set('options', this.model.get('options'));

		// if existing hasn't been saved yet, remove
		if (typeof lastVersion != 'undefined' && lastVersion.attributes.ID == lastVersion.attributes.imageID ) {
			this.model.versions.attributes.collection.remove( lastVersion );
		}

		this.phvRestoreMerge( image );

		// add model to collection
		this.model.versions.attributes.collection.add( image );
	}
});
/**
 * View to show our settings item
 *
 * @since 1.0
 */

// this lets us to call initialization and events is subviews
Huddle.NewVersionMenuItemView = function (options) { Huddle.VersionsView.apply(this, arguments); };
Huddle.NewVersionMenuItemView.extend = Huddle.VersionsView.extend;

/**
 * NewVersionMenuItemView
 */
_.extend( Huddle.NewVersionMenuItemView.prototype, Huddle.VersionsView.prototype, {
	tagName: 'li',
	template: wp.template('new-version'),
	className: 'ph-project-action ph-new-version'
});
/**
 * View to show our settings item
 *
 * @since 1.0
 */

// this lets us to call initialization and events is subviews
Huddle.ShowVersionMenuItemView = function (options) { Huddle.VersionsView.apply(this, arguments); };
Huddle.ShowVersionMenuItemView.extend = Huddle.VersionsView.extend;

/**
 * ShowVersionMenuItemView
 */
_.extend( Huddle.ShowVersionMenuItemView.prototype, Huddle.VersionsView.prototype, {
	tagName: 'li',
	template: wp.template('show-version'),
	className: 'ph-project-action ph-show-version'
});
Huddle.VersionImageView = Huddle.VersionsView.extend({
	template: wp.template( 'versions-image' ),
	className: 'ph-version-image-inner'
});
Huddle.VersionListItemView = Huddle.VersionsView.extend({
    template: wp.template('versions-list-item'),
    className: 'ph-version',

    events: {
        'click': 'clickHandler',
        'click .ph-restore': 'restoreImage'
    },

    ready: function () {
        // add current version class to current version
        if (this.model.get('id') == this.options.current) {
            this.$el.addClass('ph-version-selected ph-current-version');
        } else {
            this.$el.removeClass('ph-version-selected ph-current-version');
        }
    },

    /**
     * Handles click event for item
     */
    clickHandler: function () {
        this.clickClass();
        this.model.trigger('loadImage', this.model);
    },
    
    clickClass: function () {
        jQuery('.ph-version').removeClass('ph-version-selected');
        this.$el.addClass('ph-version-selected');
    },

    restoreImage: function () {
        this.model.trigger('restoreImage', this.model);
    }
});
/**
 * Modal view for versions popup
 */
Huddle.VersionsModal = Huddle.View.extend({
    template: wp.template('versions-modal'),
    id: "backbone_versions_modal",

    /**
     * Modal click events
     */
    events: {
        "click .backbone_modal-close": "closeModal",
        "click #btn-cancel": "closeModal"
    },

    initialize: function () {
        // fetch maybe
        this.maybeFetch();

        // version collection listeners
        this.listenTo(this.model.versions.attributes.collection, 'loadImage', this.loadImage);
        this.listenTo(this.model.versions.attributes.collection, 'restoreImage', this.restoreImage);

        // when new version is added, be sure to fetch old version
        this.listenTo(this.model.versions, 'change:fetched', this.loadViews);
    },

    /**
     * Fetch or add versions
     */
    maybeFetch: function () {
        this.model.versions.get('fetched') === false ? this.fetchVersions() : this.addVersions();
    },

    /**
     * Fetches versions from the server
     */
    fetchVersions: function () {
        this.model.versions.attributes.collection.fetch({
            data: {
                image_id: this.model.versions.attributes.originalID,
                action: 'phv_fetch_versions',
                nonce: phVersion.phNonce // pass our custom nonce
            },
            success: _.bind(function () {
                // set fetched boolean
                this.model.versions.set('fetched', true);
            }, this),
            remove: false
        });

        this.model.versions.attributes.collection.trigger('updateVersions');
    },

    /**
     * Adds all versions to ph-versions div
     * scrolls to bottom
     */
    addVersions: function () {
        // add versions
        _.each(this.model.versions.attributes.collection.models, function (item) {
            this.views.add('.ph-versions', new Huddle.VersionListItemView({
                model: item,
                current: this.model.attributes.ID
            }));
        }, this);

        // scroll to bottom
        var versionsList = jQuery('.ph-versions-list');
        if (typeof versionsList[0] != 'undefined') {
            versionsList.scrollTop(versionsList[0].scrollHeight);
        }
    },

    /**
     * Load views after fetch
     * Animates the views into the sidebar
     */
    loadViews: function () {
        var base = this;
        // empty versions div
        jQuery('.ph-versions').stop().animate({'opacity': 0}, 200, function () {
            jQuery(this).empty();

            // add versions
            base.addVersions();

            // animate opacity
            jQuery(this).animate({'opacity': 1}, 200);
        });
    },

    /**
     * Loads the image into the display area
     *
     * @param model object Model to load
     */
    loadImage: function (model) {
        this.views.set('.ph-version-display-wrap', new Huddle.VersionImageView({
            model: model
        }));
    },

    /**
     * Set model with these new attributes
     *
     * @param model object Model of clicked element
     */
    restoreImage: function (model) {
        // close modal
        this.closeModal(false);
    },

    /**
     * Closes the modal and cleans up after the instance.
     *
     * @param e {object} A jQuery-normalized event object.
     */
    closeModal: function (e) {
        typeof e.preventDefault == 'function' && e.preventDefault();

        // Undelegate
        this.undelegateEvents();

        // Remove focus and body css
        jQuery(document).off("focusin");
        jQuery("body").removeClass('ph-modal-no-overflow');

        // remove and unbind
        this.$el.removeData().unbind();

        //Remove view from DOM
        this.remove();

        // Remove
        Backbone.View.prototype.remove.call(this);
    }
});
