/**
 * Collection to store all the images for this post
 *
 * @extends BaseCollection Sync, save, fetch, update functions with app-ajax
 *
 * @since 1.0
 */
Huddle.ImageVersionsCollection = BaseCollection.extend( {
	// Use image model for this collection
	model: Huddle.Image,

	initialize: function () {
		this.listenTo( this, 'add', this.setVersionNumbers );
		this.listenTo( this, 'updateVersions', this.setVersionNumbers );
	},

	/**
	 * Sort by date
	 * @param m Model
	 * @returns {number} Milliseconds since creation
	 */
	comparator: function (m) {
		return +new Date(m.get('isoDate'));
	},

	/**
	 * Update the order attribute for all comments
	 *
	 * @param model {object} Model
	 * @param options {object} Options
	 * @param silent {bool} Set silently or not
	 */
	setVersionNumbers: function ( model, options, silent ) {
		_.each( this.models, function( image ) {
			image.set( {
				version: this.indexOf( image ) + 1
			}, {
				silent: typeof silent == 'boolean' && silent ? silent : false
			} );
		}, this );
	},

	/**
	 *
	 * @param model
	 */
	setCurrent: function( model ){
		// remove current from all models
		this.clearCurrent();

		// set in added model
		var current = this.get(model);
		current.set( 'currentVersion', true );
	},

	/**
	 * Clears current attribute in all models
	 * @param model
	 */
	clearCurrent: function() {
		_.each( this.models, function( image ) {
			image.set( 'currentVersion', false );
		}, this);
	}
});