/**
 * Model to store our individual parent comments with location
 *
 * @extends VersionsModel Sync, save, fetch, update functions with app-ajax
 *
 * @since 1.0
 */
Huddle.VersionsCollectionModel = BaseModel.extend({

	defaults: {
		collection: false,
		originalID: false,
		current: false,
		fetched: false
	},

	initialize: function() {
		// when model is added, check if should be current
		this.listenTo( this.attributes.collection, 'add', this.setCurrent );
		this.listenTo( this.attributes.collection, 'restoreImage', this.setPointer );
		this.listenTo( this.attributes.collection, 'restoreImage', this.bubbleRestore );
	},

	/**
	 * When image is restored, set current pointer
	 *
	 * @param model
	 */
	setPointer: function( model ) {
		this.set( 'current', model.id );
		this.setCurrent( model );
	},

	/**
	 * Manually bubble up restore event
	 * @param model
	 */
	bubbleRestore: function( model ) {
		this.trigger( 'restoreImage', model );
	},

	/**
	 * Set correct model to current version
	 * @param model
	 */
	setCurrent: function( model ){
		// remove current from all models
		this.clearCurrent();

		// if no current item is set, set to last in collection
		if ( ! this.attributes.current ) {
			var lastModel = this.attributes.collection.last();
			lastModel.set( 'currentVersion', true );

			return;
		}

		if ( this.attributes.current == model.id ) {
			// set in added model
			model.set( 'currentVersion', true );
		}
	},

	/**
	 * Clears current attribute in all models
	 * @param model
	 */
	clearCurrent: function() {
		_.each( this.attributes.collection.models, function( image ) {
			image.set( 'currentVersion', false );
		}, this);
	}
});