/**
 * Hook into ImageView initialize method
 */
wp.hooks.addAction('Huddle.ImageView.initialize', function( view ){
	view.phvInitialize();
});

// cache original events
var events = Huddle.ImageView.prototype.events;

/**
 * Extend the original image view
 * Adds new events, subviews and methods for ph versions
 */
_.extend( Huddle.ImageView.prototype, {

	// Add new events
	events: function () {
		return _.extend({}, events, {
			'click .ph-show-version': 'versionClick',
			'click .ph-new-version': 'newVersionClick'
		});
   },

	phvInitialize: function () {

		// listen for change to model and render
		this.listenTo( this.model, 'change', this.render );

		// when restoreImage event, swap out model in this view
		this.listenTo( this.model.versions, 'restoreImage', this.phvRestoreMerge );

		// add our menu items
		this.phvMenuItems();

		// bind this
		_.bindAll( this, 'selectNewVersion', 'addNewVersion' );
	},

	phvMenuItems: function() {
		// only add if model has been saved
		if ( this.model.attributes.ID == this.model.attributes.imageID ) {
			return;
		}

		// show versions
		this.views.add( '.ph-settings-menu', new Huddle.ShowVersionMenuItemView({
			model: this.model
		}), {
			at: 0
		});

		// new versions
		this.views.add( '.ph-settings-menu', new Huddle.NewVersionMenuItemView({
			model: this.model
		}), {
			at: 0
		});

	},

	/**
	 * Extend new model attributes
	 * @param model
	 */
	phvRestoreMerge: function( model ) {
		this.model.set( _.extend( {}, this.model.attributes, model.attributes ) );
	},

	/**
	 * Versions click handler
	 *
	 * @param e Click event
	 */
	versionClick: function( e ) {
		// prevent default action
		e.preventDefault();

		// create new versions modal view
		this.versionsModal = new Huddle.VersionsModal( {
			model: this.model
		} );

		// render versions modal view
		this.versionsModal.injectTo( 'body' );
	},

	/**
	 * New version click handler
	 *
	 * @param e Click Event
	 */
	newVersionClick: function( e ) {
		// prevent default action
		e.preventDefault();

		// open file frame
		this.phvOpenFileFrame( e );
	},

	/**
	 * Creates or Opens Existing File Frame
	 * @param e
	 */
	phvOpenFileFrame: function( e ) {
		// If the media frame already exists, reopen it.
		if ( this.version_file ) {
			this.version_file.open();
			return;
		}

		// Create the media frame
		this.version_file = wp.media( {
			title: jQuery( e.target ).data( 'uploader-title' ),
			button: {
				text: jQuery( e.target ).data( 'uploader-button-text' )
			},
			multiple: false  // Set to true to allow multiple files to be selected
		} );

		this.version_file.on( 'select', this.selectNewVersion );

		// Finally, open the modal
		this.version_file.open();
	},

	/**
	 * Gets and maps selection
	 */
	selectNewVersion: function() {
		// When an image is selected, run a callback.
		var selection = this.version_file.state().get( 'selection' );

		if ( selection.length ) {
			selection.map( this.addNewVersion );
			// Restore the main post ID
			wp.media.model.settings.post.id = this.wp_media_post_id;
		}
	},

	/**
	 * Handles selection mapping
	 * @param attachment selection
	 */
	addNewVersion: function( attachment ) {
		var imageURL = false;
		if ( typeof attachment.get('sizes').large == 'undefined' ) {
			imageURL = attachment.get('sizes').full.url
		} else {
			imageURL = attachment.get('sizes').large.url
		}

		// create new image
		var image = new Huddle.Image({
			id: attachment.get('id'),
			ID: attachment.get('id'),
            thumbnail: imageURL,
            url: attachment.get('sizes').full.url,
			imageID: attachment.get('id'),
			title: attachment.get('title'),
			parent: this.model.versions.get('originalID')
		});

		// get last version in collection
		var lastVersion = this.model.versions.get('collection').last();

        // options should stay the same as previous image
        image.set('options', this.model.get('options'));

		// if existing hasn't been saved yet, remove
		if (typeof lastVersion != 'undefined' && lastVersion.attributes.ID == lastVersion.attributes.imageID ) {
			this.model.versions.attributes.collection.remove( lastVersion );
		}

		this.phvRestoreMerge( image );

		// add model to collection
		this.model.versions.attributes.collection.add( image );
	}
});