/**
 * Modal view for versions popup
 */
Huddle.VersionsModal = Huddle.View.extend({
    template: wp.template('versions-modal'),
    id: "backbone_versions_modal",

    /**
     * Modal click events
     */
    events: {
        "click .backbone_modal-close": "closeModal",
        "click #btn-cancel": "closeModal"
    },

    initialize: function () {
        // fetch maybe
        this.maybeFetch();

        // version collection listeners
        this.listenTo(this.model.versions.attributes.collection, 'loadImage', this.loadImage);
        this.listenTo(this.model.versions.attributes.collection, 'restoreImage', this.restoreImage);

        // when new version is added, be sure to fetch old version
        this.listenTo(this.model.versions, 'change:fetched', this.loadViews);
    },

    /**
     * Fetch or add versions
     */
    maybeFetch: function () {
        this.model.versions.get('fetched') === false ? this.fetchVersions() : this.addVersions();
    },

    /**
     * Fetches versions from the server
     */
    fetchVersions: function () {
        this.model.versions.attributes.collection.fetch({
            data: {
                image_id: this.model.versions.attributes.originalID,
                action: 'phv_fetch_versions',
                nonce: phVersion.phNonce // pass our custom nonce
            },
            success: _.bind(function () {
                // set fetched boolean
                this.model.versions.set('fetched', true);
            }, this),
            remove: false
        });

        this.model.versions.attributes.collection.trigger('updateVersions');
    },

    /**
     * Adds all versions to ph-versions div
     * scrolls to bottom
     */
    addVersions: function () {
        // add versions
        _.each(this.model.versions.attributes.collection.models, function (item) {
            this.views.add('.ph-versions', new Huddle.VersionListItemView({
                model: item,
                current: this.model.attributes.ID
            }));
        }, this);

        // scroll to bottom
        var versionsList = jQuery('.ph-versions-list');
        if (typeof versionsList[0] != 'undefined') {
            versionsList.scrollTop(versionsList[0].scrollHeight);
        }
    },

    /**
     * Load views after fetch
     * Animates the views into the sidebar
     */
    loadViews: function () {
        var base = this;
        // empty versions div
        jQuery('.ph-versions').stop().animate({'opacity': 0}, 200, function () {
            jQuery(this).empty();

            // add versions
            base.addVersions();

            // animate opacity
            jQuery(this).animate({'opacity': 1}, 200);
        });
    },

    /**
     * Loads the image into the display area
     *
     * @param model object Model to load
     */
    loadImage: function (model) {
        this.views.set('.ph-version-display-wrap', new Huddle.VersionImageView({
            model: model
        }));
    },

    /**
     * Set model with these new attributes
     *
     * @param model object Model of clicked element
     */
    restoreImage: function (model) {
        // close modal
        this.closeModal(false);
    },

    /**
     * Closes the modal and cleans up after the instance.
     *
     * @param e {object} A jQuery-normalized event object.
     */
    closeModal: function (e) {
        typeof e.preventDefault == 'function' && e.preventDefault();

        // Undelegate
        this.undelegateEvents();

        // Remove focus and body css
        jQuery(document).off("focusin");
        jQuery("body").removeClass('ph-modal-no-overflow');

        // remove and unbind
        this.$el.removeData().unbind();

        //Remove view from DOM
        this.remove();

        // Remove
        Backbone.View.prototype.remove.call(this);
    }
});