<?php
/**
 * PH Image Versions Data
 *
 * This class provides additional data to the
 *
 * @package		PH Image Versions
 * @copyright	Copyright (c) 2015, Andre Gagnon
 * @license		http://opensource.org/license/gpl-2.0.php GNU Public License
 * @since		1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Extend image data through filters
 *
 * Class PH_VERSIONS_IMAGE
 *
 * @since 1.0.0
 */
class PH_VERSIONS_IMAGE {

	/**
	 * Register actions
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_filter( 'ph_image_data', array( $this, 'add_version_data' ), 20 );
	}

	/**
	 * Gets parent post data from image id
	 *
	 * @param $post_id
	 *
	 * @return array Array of post objects
	 */
	public function get_parents( $post_id ) {

		// get parent post ids
		$parents = get_post_ancestors( $post_id );

		// start array
		$parents_output = array();

		if ( $parents && is_array($parents) ) {
			foreach( $parents as $key => $parent ) {
				// get image data from image id
				$image = PH()->image->get_image( $parent );

				if ( ! $image ) {
					continue;
				}

				$parents_output[] = $image;
			}
		}

		return $parents_output;
	}

	/**
	 * Gets children post data from image id
	 *
	 * @param $post_id
	 *
	 * @return array Array of post objects
	 */
	public function get_children( $post_id ) {

		$children = ph_get_all_post_children( $post_id );

		// start array
		$children_output = array();
		foreach( $children as $child ) {
			// get image data from image id
			$image = PH()->image->get_image( $child );

			if ( ! $image ) {
				continue;
			}

			$children_output[] = $image;
		}

		return $children_output;
	}

	/**
	 * Adds dates to image data array
	 *
	 * @param $image_props array Image properties
	 *
	 * @return array
	 */
	public function add_version_data( $image_props ) {
		if ( ! isset( $image_props['ID'] ) ) {
			return $image_props;
		}
		$image_props['createDate'] = get_the_date( get_option( 'date_format' ), (int) $image_props['ID'] );
		$image_props['createTime'] = get_the_time( 'g:i a', (int) $image_props['ID'] );
		$image_props['isoDate'] = get_the_date('c', (int) $image_props['ID']);

		return $image_props;
	}
}