<?php
/**
 * Image Meta Box Functions
 *
 * Functions to apply to images meta box
 *
 * @package     PH Image Versions
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Add version hidden field to each image in metabox
 *
 * @since 1.0.0
 */
function phv_add_version_field() {
	echo '<input type="hidden" name="ph-project-parent[]" value="{{ data.parent }}" />';
}

add_action( 'ph_meta_box_image_hidden_fields', 'phv_add_version_field' );

/**
 * Adds version $_POST value from hidden fields
 *
 * @param $collection array Values to save
 *
 * @since 1.0.0
 * @return array New values with ours added
 */
function phv_add_hidden_version_field( $collection ) {
	$collection['parent'] = isset( $_POST['ph-project-parent'] ) ? (array) $_POST['ph-project-parent'] : array();

	return $collection;
}

add_filter( 'ph_meta_box_image_save_hidden_fields', 'phv_add_hidden_version_field' );

/**
 * If this is a version, add to last child
 *
 * @param $post_args
 * @param $image array Image data
 * @param $post object Post object
 * @param $images array All images
 *
 * @return array Filtered post arguments with parent properly set
 */
function phv_add_parent_argument( $post_args, $image, $post, $images ) {

	// make sure it's not an attachment
	if ( get_post_type( $image['parent'] ) != 'project_image' ) {
		return $post_args;
	}

	// check if version already has any children. We want to add to the last child
	$children = ph_get_all_post_children( $image['parent'] );

	// if there are no children, use current version
	if ( ! isset( $children ) || empty( $children ) ) {
		$post_args['post_parent'] = $image['parent'];
	} else {
		$post_args['post_parent'] = (int) end( $children );
	}

	return $post_args;
}

add_filter( 'ph_create_image_post', 'phv_add_parent_argument', 10, 4 );