<?php
/**
 * Misc Functions
 *
 * Misc functions used througout the plugin
 *
 * @package     PH Image Versions
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Gets all post children and grandchildren
 *
 * Essentially the opposite of get_post_ancestors
 *
 * @param $post_id
 *
 * @return array
 */
function ph_get_all_post_children( $post_id ) {

	// get_children args
	$args = array(
		'post_parent' => $post_id,
		'post_type'   => 'project_image',
		'numberposts' => 1,
		'post_status' => 'publish'
	);

	// get children (one level deep)
	$child = get_children( $args );

	// bail if no children
	if ( ! $child || ! is_array( $child ) ) {
		return array();
	}

	$ancestors = array();

	$id = $ancestors[] = current($child)->ID;

	// loop through and get all children
	while ( $ancestor = get_children( array(
		'post_parent' => $id,
		'post_type'   => 'project_image',
		'numberposts' => 1,
		'post_status' => 'publish'
	) ) ) {
		// Loop detection: If the ancestor has been seen before, break.
		if ( empty( $ancestor ) || ( current($ancestor)->ID == $id ) || in_array( current($ancestor)->ID, $ancestors ) )
			break;

		$id = $ancestors[] = current($ancestor)->ID;
	}

	return $ancestors;
}