<?php
/**
 * Project Functions
 *
 * Add filter project class functinos
 *
 * @package     PH Image Versions
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Adds date format option to javascript
 * @param $project
 */
function phv_add_date_format_option( $project ) {
	$project['options']['date_format'] = get_option( 'date_format' );
	return $project;
}
add_filter( 'ph_project_data', 'phv_add_date_format_option' );


/**
 * Checks if post_id exists in project meta
 * If not, remove project_id from meta so it doesn't get re-added in untrash
 *
 * This is so revisions are not automatically added to projects
 */
function ph_check_remove_project_id( $post_id ) {
	// check post type
	if ( get_post_type( $post_id ) != 'project_image' ) {
		return;
	}

	// get project it belongs to
	$project_id = get_post_meta( $post_id, 'ph_project_id', true );

	// get image post ids
	$images = get_post_meta( $project_id, 'ph_project_images', true );

	// if post id isn't currently part of project, remove meta
	if ( ! in_array( $post_id, $images ) ) {
		delete_post_meta( $post_id, 'ph_project_id' );
	}

}
add_action( 'wp_trash_post', 'ph_check_remove_project_id' );

/**
 * Even if image is moved to trash, it should be added
 * to the project images list if it's selected.
 *
 * @param $model
 */
function phv_make_current( $model ) {

	// validate post ID with server
	$url = parse_url( wp_get_referer() );
	parse_str($url['query'], $query);
	$project_id = (int) $query['post'];

	// get project images from project
	$old = (array) get_post_meta( $project_id, 'ph_project_images', true );

	// if it's not part of the array and is a version, add it
	if ( ! in_array( $model['ID'], $old ) && $model['parent'] ) {
		$old[] = $model['ID'];
		update_post_meta( $project_id, 'ph_project_images', $old );
	}
}
add_action( 'ph_move_image_to_trash_before', 'phv_make_current', 10, 2 );