<?php
/**
 * Version Scripts
 *
 * Scripts and stylesheets used for versions
 *
 * @package     PH Image Versions
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Add your custom stylesheet
 * Be sure to change 'my' to your own prefix to prevent conflicts
 */
function phv_admin_scripts( $hook ) {
	// get post type
	global $post_type;

	// bail out early if we are not on a project add/edit screen.
	if ( 'ph-project' != $post_type || ( $hook !== 'post.php' && $hook !== 'post-new.php' ) ) {
		return false;
	}

	// store javascript directory
	$js_dir = PH_VERSIONS_PLUGIN_URL . 'assets/js/';

	// store javascript directory
	$css_dir = PH_VERSIONS_PLUGIN_URL . 'assets/css/';

	// add versions script
	wp_enqueue_script( 'ph-versions-script', $js_dir . 'ph-versions.admin.js', array(
		'jquery',
		'backbone',
		'underscore',
		'wp-backbone',
		'project-huddle-admin-js'
	), PH_VERSION, true );

	// add stylesheet
	wp_enqueue_style( 'ph-versions-style', $css_dir . 'ph-image-versions.css', array(), PH_VERSION );

	// localize nonce and admin ajax
	wp_localize_script( 'ph-versions-script', 'phVersion', array(
		'ajaxurl' => esc_url( admin_url( 'admin-ajax.php' ) ),
		'phNonce' => wp_create_nonce( 'ph-version-nonce' ),
		'translations' => array(
			'confirmTrash' => __( 'This will remove ALL versions of this image from your project!', 'project-huddle' )
		)
	));
}
add_action( 'admin_enqueue_scripts', 'phv_admin_scripts', 99 );

/**
 * Add your custom stylesheet
 * Be sure to change 'my' to your own prefix to prevent conflicts
 */
function phv_project_scripts( $hook ) {
	// get post type
	global $post_type;

	// bail out early if we are not on a project add/edit screen.
	if ( 'ph-project' != $post_type ) {
		return false;
	}

	// store javascript directory
	$js_dir = PH_VERSIONS_PLUGIN_URL . 'assets/js/';

	// store javascript directory
	$css_dir = PH_VERSIONS_PLUGIN_URL . 'assets/css/';

	// add versions script
	wp_enqueue_script( 'phv-versions-script', $js_dir . 'ph-versions.js', array(
			'jquery',
			'backbone',
			'underscore',
			'wp-backbone',
			'project-huddle'
	), PH_VERSION, false );

	// localize nonce and admin ajax
	wp_localize_script( 'phv-versions-script', 'phVersion', array(
			'ajaxurl' => esc_url( admin_url( 'admin-ajax.php' ) ),
			'phNonce' => wp_create_nonce( 'ph-version-nonce' )
	));
}
add_action( 'wp_enqueue_scripts', 'phv_project_scripts' );

function phv_script_handles( $scripts = array() ){
	$scripts[] = 'phv-versions-script';

	return $scripts;
}
add_filter( 'ph_allowed_scripts', 'phv_script_handles' );