<?php
/**
 * Project Options Meta Box
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )  exit;

/**
 * PH_Meta_Box_Project_Options Class
 *
 * @since 1.0
 */
class PH_Meta_Box_Website_Options {

	public static $fields = array();

	public static function meta_fields() {
		$fields = apply_filters( 'ph_website_meta_box_options', array(
			array(
				'id'      => 'project_access',
				'label'   => __( 'Project Access', 'project-huddle' ),
				'type'    => 'radio',
				'prefix'  => false,
				'options' => array(
					'login'  => 'Must be logged in',
					'link'   => 'Anyone with the Project Access Link',
					'public' => 'Anyone who visits the site',
				),
				'default' => 'login'
			),
		) );

		return $fields;
	}

	/**
	 * Output the metabox
	 *
	 * @access public
	 * @since  1.0
	 * @return void
	 */
	public static function output( $post ) {

		// create nonce field
		wp_nonce_field( 'project_huddle_save_data', 'project_huddle_meta_nonce' );

		$fields = self::meta_fields(); ?>

		<div id="project_options_container" class="ph_meta_box">

			<?php
				foreach( $fields as $field ) {
					PH()->meta->display_field( $field, $post );
				}
			?>

		</div>

		<?php
	}

	/**
	 * Save meta box data
	 *
	 * @access public
	 * @since  1.0
	 * @return void
	 */
	public static function save( $post_id, $post ) {

		$fields = self::meta_fields();

		foreach( $fields as $field ) {
			$value = self::sanitize_field( $field );
			update_post_meta( $post_id, 'ph_' . $field['id'], esc_attr( $value ) );
		}

		// if password is empty, make public
		if (empty($post->post_password) || ! isset($_POST['ph_project_access']) || $_POST['ph_project_access'] == 'password' ) {
			update_post_meta( $post_id, 'ph_project_access', 'public' );
		}
	}

	public static function sanitize_field( $field ) {

		$value = isset( $_POST['ph_' . $field['id'] ] ) ? $_POST['ph_' . $field['id'] ] : false;

		switch( $field['type'] ) {
			case 'checkbox':
				$value = $value ? esc_html( $value ) : 'off';
				break;
		}

		return $value;
	}
}