<?php
/**
 * API Functions
 *
 * Process the API Requests
 *
 * @package     ProjectHuddle
 * @subpackage  PH Website Versions
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.2.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class PH_Website_Actions {

	/**
	 * Variable to store our Webpage ID
	 *
	 * @var integer
	 */
	protected $webpage_id;

	/**
	 * Variable to store comment thread ID
	 *
	 * @var integer
	 */
	protected $thread_id;

	/**
	 * Variable to store the comment
	 *
	 * @var object
	 */
	protected $comment;

	/**
	 * Variable to store author
	 *
	 * @var object
	 */
	protected $author;

	/**
	 * Variable to store model data
	 */
	protected $data;

	/**
	 * Setup project admin
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		$this->author = wp_get_current_user();

		// projects
		add_filter( 'ph_new_website_project', array( $this, 'new_project' ) );
		add_filter( 'ph_edit_website_project', array( $this, 'edit_project' ) );

		// subscribers
		add_filter( 'ph_add_project_subscriber', array( $this, 'add_project_subscriber' ) );
		add_filter( 'ph_remove_project_subscriber', array( $this, 'remove_project_subscriber' ) );

		// pages
		add_filter( 'ph_reorder_website_page', array( $this, 'reorder_pages' ) );

		// threads
		add_filter( 'ph_get_website_thread', array( $this, 'get_thread' ) );
		add_filter( 'ph_new_website_thread', array( $this, 'new_thread' ) );
		add_filter( 'ph_edit_website_thread', array( $this, 'edit_thread' ) );
		add_filter( 'ph_resolve_website_thread', array( $this, 'resolve_thread' ) );
		add_filter( 'ph_assign_website_thread', array( $this, 'assign_thread' ) );
		add_filter( 'ph_trash_website_thread', array( $this, 'delete_thread' ) );
		add_filter( 'ph_reorder_website_thread', array( $this, 'reorder_threads' ) );

		// comments
		add_filter( 'ph_new_website_comment', array( $this, 'new_comment' ) );
		add_filter( 'ph_edit_website_comment', array( $this, 'edit_comment' ) );
		add_filter( 'ph_trash_website_comment', array( $this, 'delete_comment' ) );
	}

	public function new_project( $data ) {
		$this->data = $data->get_params();

//		if ( ! isset( $this->data['url'] ) || ! filter_var( $this->data['url'], FILTER_VALIDATE_URL ) ) {
//			return new WP_Error( 'invalid_email', __('Please enter a valid URL.', 'project-huddle'), array( 'status' => 404 ) );
//		}
//
//		$api_key = ph_generate_api_key();

		return $this->data;
	}

	public function edit_project( $data ) {
		$this->data = $data->get_params();

		if ( isset( $this->data['title'] ) ) {
			wp_update_post(array(
				'ID'           => (int)$this->data['id'],
				'post_title'   => esc_html($this->data['title']),
			));
		}

		return $this->data;
	}

	/**
	 * Add project subscriber
	 *
	 * @param array $data Needs ID and ids
	 *
	 * @return mixed
	 */
	public function add_project_subscriber( $data ) {
		$this->data = $data->get_params();

		if ( ! isset( $this->data['email'] ) || ! is_email( $this->data['email'] ) ) {
			return $this->data;
		}

		// get subscribed
		$emails = (array) get_post_meta( (int) $this->data['id'], 'ph_project_emails_enable', true );
		array_push( $emails, sanitize_email( $this->data['email'] ) );

		// auto email user
		do_action( 'ph_new_email_admin_subscribe', array( $this->data['email'] ), wp_get_current_user(), $this->data['id'] );

		// update meta
		update_post_meta( (int) $this->data['id'], 'ph_project_emails_enable', $emails );
		update_post_meta( (int) $this->data['id'], 'ph_project_emails', $emails );

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		// return model success
		return $this->data;
	}

	/**
	 * Add project subscriber
	 *
	 * @param array $data Needs ID and ids
	 *
	 * @return mixed
	 */
	public function remove_project_subscriber( $data ) {
		$this->data = $data->get_params();
		$this->body = $data->get_body_params();

		// update assigned
		if ( isset( $this->body['email'] ) ) {
			// get subscribed
			$emails = (array) get_post_meta( (int) $this->data['id'], 'ph_project_emails_enable', true );

			// get all in case there are duplicates
			if ( $keys = array_keys( $emails, $this->body['email'] ) ) {
				foreach ( $keys as $key ) {
					unset( $emails[ $key ] );
				}
				update_post_meta( (int) $this->data['id'], 'ph_project_emails_enable', $emails );
				update_post_meta( (int) $this->data['id'], 'ph_project_emails', $emails );
			}
		}

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		// return model success
		return $this->data;
	}

	/**
	 * Reorder pages
	 *
	 * @param array $data Needs ID and ids
	 *
	 * @return mixed
	 */
	public function reorder_pages( $data ) {
		$this->data = $data->get_params();

		// store order in user meta
		update_user_meta( $this->data['user_id'], 'pages_order_' . $this->data['id'], $this->data['ids'] );

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		return $this->data;
	}

	/**
	 * Reorder pages
	 *
	 * @param array $data Needs ID and ids
	 *
	 * @return mixed
	 */
	public function reorder_threads( $data ) {
		$this->data = $data->get_params();

		// store order in user meta
		update_user_meta( $this->data['user_id'], 'threads_order_' . $this->data['id'], $this->data['ids'] );

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		return $this->data;
	}

	/**
	 * Get website thread
	 *
	 * @param array $data Model data
	 *
	 * @return array Updated model data
	 */
	public function get_comment( $data = array() ) {
		$this->data = ! empty( $data ) ? $data->get_params() : $this->data;

		$thread = PHW()->thread->get_location_info( $this->data['id'] );

		// add filters and actions
		$thread = $this->filter_action( __FUNCTION__, $thread );

		return $thread;
	}

	/**
	 * Create New Website Comment Thread
	 * Also adds first comment
	 *
	 * @param array $data Model data
	 *
	 * @return array Updated model data
	 */
	public function new_thread( $data ) {
		$this->data = $data->get_params();

		// get webpage id by current location
		$this->data['webpage_id'] = PHW()->page->get_webpage_id( $this->data['website_id'], $this->data['location'] );

		// if webpage doesn't exist, create it
		if ( ! $this->data['webpage_id'] ) {
			// create page
			$this->data['webpage_id'] = PHW()->page->new_page( $this->data['page_title'] );
			// add to site meta
			PHW()->website->add_page( array(
				'website_id' => $this->data['website_id'],
				'webpage_id' => $this->data['webpage_id'],
				'location'   => $this->data['location']
			) );
		}

		// add thread
		$this->data['comment_post_ID'] = $this->data['id'] = (int) PHW()->thread->add_thread( $this->data['comment_content'], $this->data );
		$this->data['url'] = get_permalink($this->data['id']);

		// add location to website post
		PHW()->page->add_thread( array(
			'webpage_id' => $this->data['webpage_id'],
			'thread_id'  => $this->data['comment_post_ID'],
			'assigned'   => $this->data['assigned'],
		) );

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		// update live model on success
		return $this->data;
	}

	/**
	 * Edit Thread
	 *
	 * @param array $data Model data
	 *
	 * @return array Model
	 */
	public function edit_thread( $data ) {
		$this->data = $data->get_params();

		if ( ! isset( $data['id'] ) || ! $data['id'] ) {
			wp_send_json_error( __( 'Please enter a thread id.', 'project-huddle' ) );
		}

		if ( ! current_user_can( 'moderate_ph-website_comments', $this->data['website_id'] ) ) {
			wp_send_json_error( __( 'You don\'t have permission to do that.', 'project-huddle' ) );
		}

		// marge defaults
		$data = wp_parse_args( $this->data, array(
			'path'           => false,
			'order'          => 0,
			'relativeX'      => 0,
			'relativeY'      => 0,
			'html'           => '',
			'resX'           => 0,
			'resY'           => 0,
			'resolved'       => 0,
			'browser'        => '',
			'browserVersion' => '',
			'browserOS'      => '',
			'webpage_id'     => 0,
			'website_id'     => 0
		) );

		// update each
		foreach($data as $key => $item) {
			if ( $data[ $key ] ) {
				update_post_meta($data['id'], $key, $data[$key]);
			}
		}

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		// return model success
		return $this->data;
	}

	/**
	 * Resolve/Unresolve thread
	 * @param $data
	 *
	 * @return mixed
	 */
	public function resolve_thread( $data ) {
		$this->data = $data->get_params();

		// update resolved
		if ( isset( $this->data['resolved'] ) ) {
			update_post_meta( (int) $this->data['id'], 'resolved', $this->data['resolved'] );
		}

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		return $this->data;
	}

	/**
	 * Assign/Unassign Thread
	 */
	public function assign_thread( $data ) {
		$this->data = $data->get_params();

		// update assigned
		if ( isset( $this->data['assigned'] ) ) {
			update_post_meta( (int) $this->data['id'], 'assigned', (int) $this->data['assigned'] );
		}

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		return $this->data;
	}

	/**
	 * Delete Thread
	 *
	 * @param array $data Model data
	 *
	 * @return array Model
	 */
	public function delete_thread( $data ) {
		$this->data = $data->get_params();

		// trash post
		wp_trash_post( $this->data['id'] );

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		// return success
		return $this->data;
	}

	/**
	 * Updates comment content
	 *
	 * @param array $data Model data
	 *
	 * @return array Updated model data
	 */
	public function edit_comment( $data ) {
		$this->data = $data->get_params();

		// update comment
		$updated = wp_update_comment( array(
			'comment_ID'      => (int) $this->data['id'],
			'comment_content' => wp_kses_post( $this->data['comment_content'] )
		) );

		// check success
		if ( ! $updated ) {
			error_log( 'ProjectHuddle: Method "' . __METHOD__ . '" could not update comment.' );
			wp_send_json_error( __( 'Something went wrong. Please reload the page and try again.', 'project-huddle' ) );
		}

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		return $this->data;
	}

	/**
	 * Creates new comment
	 *
	 * @param array $data Model data
	 *
	 * @return array Updated model data
	 */
	public function new_comment( $data = array() ) {
		$this->data = ! empty( $data ) ? $data->get_params() : $this->data;

		// get comment thread id
		$this->thread_id = $this->data['comment_post_ID'];

		// add comment text after post success
		$this->comment = PHW()->comment->create( array(
			'thread_id'       => $this->data['comment_post_ID'],
			'comment_content' => wp_kses_post( $this->data['comment_content'] ),
			'author_id'       => (int) $this->author->ID
		) );

		// sanitize
		$this->data['comment_content']      = wp_kses_post( $this->data['comment_content'] );
		$this->data['comment_ID']           = (int) $this->comment->comment_ID;
		$this->data['comment_author']       = esc_html( $this->comment->comment_author );
		$this->data['comment_author_email'] = esc_html( $this->comment->comment_author_email );
		$this->data['date']                 = ph_human_time_diff( mysql2date( 'U', $this->comment->comment_date, true ), current_time( 'timestamp' ) );
		$this->data['avatar']               = get_avatar( sanitize_email( $this->comment->comment_author_email ), 64 );
		$this->data['id']                   = (int) $this->comment->comment_ID;

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		// update live model on success
		return $this->data;
	}

	/**
	 * Deletes comment
	 * Also deletes thread if empty
	 *
	 * @param array $data Model data
	 *
	 * @return array Updated model data
	 */
	public function delete_comment( $data ) {
		$this->data = $data->get_params();

		// trash comment
		$trashed = wp_trash_comment( (int) $this->data['id'] );

		// trash comment location post if comment thread is empty
		if ( isset( $this->data['comment_post_ID'] ) ) {
			$number = get_comments_number( $this->data['comment_post_ID'] );

			if ( $number == '0' ) {
				wp_trash_post( $this->data['comment_post_ID'] );
			}
		}

		if ( ! $trashed ) {
			error_log( 'ProjectHuddle: Method "' . __METHOD__ . '" could not trash comment.' );
			wp_send_json_error( __( 'Something went wrong. Please reload the page and try again.', 'project-huddle' ) );
		}

		// add filters and actions
		$this->data = $this->filter_action( __FUNCTION__, $this->data );

		// send update
		return $this->data;
	}

	/**
	 * Add Filter and actions for each function
	 *
	 * @param $name string Function name
	 * @param $data array Data to filter
	 *
	 * @return mixed
	 */
	public function filter_action( $name, $data ) {
		// filter model data
		$data = apply_filters( 'ph_website_filter_' . $name, $data );

		// comment action
		do_action( 'ph_website_' . $name, $this->data );

		return $data;
	}
}