<?php
/**
 * Functions for getting/creating/updating/deleting
 * ProjectHuddle models.
 *
 * Use these instead of direct class references for future compatibility
 */

if ( ! function_exists( 'ph_get_website' ) ) :
	/**
	 * Get Website
	 *
	 * @param int   $id Website ID
	 * @param array $params
	 * @param array $query_params
	 */
	function ph_get_website( $id = null, $params = array(), $query_params = array() ) {
		return PHW()->website->get_item( $id, $params, $query_params );
	}
endif;

if ( ! function_exists( 'ph_get_website_page' ) ) :
	/**
	 * Get Website
	 *
	 * @param int   $id Website ID
	 * @param array $params
	 * @param array $query_params
	 */
	function ph_get_website_page( $id = null, $params = array(), $query_params = array() ) {
		return PHW()->page->get_item( $id, $params, $query_params );
	}
endif;

if ( ! function_exists( 'ph_get_website_thread' ) ) :
	/**
	 * Get Website
	 *
	 * @param int   $id Website ID
	 * @param array $params
	 * @param array $query_params
	 */
	function ph_get_website_thread( $id = null, $params = array(), $query_params = array() ) {
		return PHW()->thread->get_item( $id, $params, $query_params );
	}
endif;

if ( ! function_exists( 'ph_get_website_comments' ) ) :
	/**
	 * Get Website
	 *
	 * @param int   $id Website ID
	 * @param array $params
	 * @param array $query_params
	 */
	function ph_get_website_comments( $id = 0, $params = array(), $query_params = array() ) {
		PHW()->thread->get_item( $id, $params, $query_params );
	}
endif;

if ( ! function_exists( 'ph_get_parents_ids' ) ) :
	/**
	 * ph_get_parents_ids
	 */
	function ph_get_parents_ids( $object, $type = 'post' ) {
		if ( is_int( $object ) ) {
			if ( $type === 'post' ) {
				$object = get_post( $object );
			} else {
				$object = get_comment( $object );
			}
		}

		if ( ! is_object( $object ) ) {
			return false;
		}

		$parent_ids = array(
			'website' => 0,
			'page'    => 0,
			'thread'  => 0
		);

		// post or comment
		if ( isset( $object->comment_ID ) ) {
			$parent_ids['thread'] = (int) $object->comment_post_ID;
			$object = $object->comment_post_ID;
		} else {
			$object = $object->ID;
		}

		switch ( get_post_type( $object ) ) {
			case PHW()->thread->post_type :
				$parent_ids['page']    = (int) get_post_meta( $object, 'parent_id', true );
				$parent_ids['website'] = (int) get_post_meta( $parent_ids['page'], 'parent_id', true );
				break;
			case PHW()->page->post_type:
				$parent_ids['site']    = (int) get_post_meta( $object, 'parent_id', true );
				break;
			default:
				break;
		}

		return $parent_ids;
	}
endif;

if ( ! function_exists( 'ph_get_parents' ) ) :
	/**
	 * ph_get_parents
	 */
	function ph_get_parents( $object, $type = 'post' ) {
		if ( is_int($object) ) {
			if ( $type === 'post' ) {
				$object = get_post($object);
			} else {
				$object = get_comment($object);
			}
		}

		if ( ! is_object( $object ) ) {
			return false;
		}

		$parent_ids = array(
			'website' => 0,
			'page'    => 0,
			'thread'  => 0
		);

		// post or comment
		if ( isset( $object->comment_ID ) ) {
			$parent_ids['thread'] = PHW()->thread->get_item($object->comment_post_ID);
			$object = $object->comment_post_ID;
		} else {
			$object = $object->ID;
		}

		switch ( get_post_type( $object ) ) {
			case PHW()->thread->post_type :
				$thread = PHW()->thread->get_item($object);
				$page = PHW()->page->get_item($thread['parent_id']);
				$site = PHW()->website->get_item($page['parent_id']);
				$parent_ids['page'] = $page;
				$parent_ids['website'] = $site;
				break;
			case PHW()->page->post_type:
				$page = PHW()->page->get_item($object);
				$site = PHW()->website->get_item($page['parent_id']);
				$parent_ids['site'] = $site;
				break;
			default:
				break;
		}

		return $parent_ids;
	}
endif;