<?php
/**
 * Template Functions
 *
 * Functions for the templating system.
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Checks for template and includes
 * To edit this, simply place single-project.php in your theme or child theme.
 *
 * @since 1.2.0
 * @return string
 */
function ph_website_set_template( $template ) {
	global $wp;
	// Check if the single post type is     being viewed and check if template already exists
	if ( is_singular( 'ph-website' ) && ! ph_is_template( $template ) ) {
		if ( isset( $wp->query_vars['ph_apikey']) && $wp->query_vars['ph_apikey'] ) {
			$template = PH_WEBSITE_PLUGIN_DIR . 'templates/single-website-script.php';
		} else {
			$template = PH_WEBSITE_PLUGIN_DIR . 'templates/single-website.php';
		}
	}

	if ( is_singular( 'phw_comment_loc' ) && ! ph_is_template( $template ) ) {
		$template = PH_WEBSITE_PLUGIN_DIR . 'templates/single-comment-thread.php';
	}

	if ( is_singular( 'ph-webpage' ) && ! ph_is_template( $template ) ) {
		$template = PH_WEBSITE_PLUGIN_DIR . 'templates/single-website-page.php';
	}

	if ( $template ) {
		include $template;
		exit;
	}
}

add_filter( 'template_redirect', 'ph_website_set_template' );

/**
 * Adds underscore templates via filter action
 *
 * @uses ph_get_project_info to generate json data for project
 *
 * @since 1.0
 */
function ph_output_website_underscore_templates() {
	// panel
	ph_get_template('parts/website-panel.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// comments
	ph_get_template('comment/comment.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template('comment/comment-item.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template('comment/comment-dot.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// toolbar buttons
	ph_get_template('parts/website-toolbar.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template('parts/website-toolbar-buttons.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// assign
	ph_get_template('parts/website-assign.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// popup
	ph_get_template('parts/website-popup.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// filter
	ph_get_template('parts/website-filter.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );
	ph_get_template('parts/website-resolved-toggle.tmpl.php', '', '', PH_WEBSITE_PLUGIN_DIR . 'templates/' );

	// project container and data
	ph_get_template( 'parts/website.tmpl.php', array(
		'project_data' => PHW()->website->get_item()
	), '', PH_WEBSITE_PLUGIN_DIR . 'templates/');
}

// add underscore templates
add_action( 'ph_website_header', 'ph_output_website_underscore_templates', 20 );


/**
 * Adds underscore templates via filter action
 *
 * @uses ph_get_project_info to generate json data for project
 *
 * @since 1.0
 */
function ph_output_admin_underscore_templates() {
	global $typenow, $pagenow, $adminpage;
	if( 'ph-website' != $typenow ) {
		return;
	}
	// check correct page
	if ( 'post.php' != $pagenow && 'post-new.php' != $pagenow ) {
		return false;
	}

	// project container and data
	ph_get_template( 'admin/tasks.tmpl.php', array(
		'project_data' => PHW()->website->get_item()
	), '', PH_WEBSITE_PLUGIN_DIR . 'templates/');
}

// add underscore templates
add_action( 'admin_footer', 'ph_output_admin_underscore_templates', 9 );