<?php
/**
 * Project Options Meta Box
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )  exit;

/**
 * PH_Meta_Box_Project_Emails Class
 *
 * @since 1.0
 */
class PH_Meta_Box_Project_Members {

	// store meta box fields
	public static $fields = array();

	// store emails
	public static $emails = array();

	public static function meta_fields() {
		global $post;

		// get emails
		self::$emails = (array) get_post_meta( (int) $post->ID, 'ph_project_emails', true );

		$options = array();
		foreach ( self::$emails as $key => $email ) :
			if ( $email ) :
				$user = get_user_by('email', $email);
				if ( $user ) {
					$options[ $email ] = array(
						'text' => get_avatar( sanitize_email( $email ), 22 ) . ' ' . esc_html( $user->display_name )
					);
				} else {
					$options[ $email ] = array(
						'text' => get_avatar( sanitize_email( $email ), 22 ) . ' ' . sanitize_email( $email )
					);
				}
			endif;
		endforeach;

		$fields = array(
			array(
				'id'          => 'project_emails_enable',
				'type'        => 'select_multi',
				'class'       => 'ph-select2 ph-get-users ph-multiple',
				'options'     => $options,
				'default'     => ''
			)
		);

		return $fields;
	}

	/**
	 * Output the metabox
	 *
	 * @access public
	 * @since  1.0
	 * @return void
	 */
	public static function output( $post ) {

		// create nonce field
		wp_nonce_field( 'project_huddle_save_data', 'project_huddle_meta_nonce' );

		$fields = self::meta_fields(); ?>

        <div id="project_emails_container" class="ph_meta_box">

			<?php
			foreach( $fields as $field ) {
				PH()->meta->display_field( $field, $post );
			}
			?>

        </div>

		<?php
	}

	/**
	 * Save meta box data
	 *
	 * @access public
	 * @since  1.0
	 * @return void
	 */
	public static function save( $post_id, $post ) {

		$fields = self::meta_fields();

		foreach( $fields as $field ) {
			$value = self::sanitize_field( $field );

			if ( ! $value ) {
				$value = array();
			}

			if ( $field['id'] = 'project_emails_enable' ) {
				update_post_meta( $post_id, 'ph_' . $field['id'], $value );
				update_post_meta( $post_id, 'ph_project_emails', $value );

				$user = wp_get_current_user();

				/**
				 * allow actions on new email saves
				 *
				 * @returns array of new email addresses added
				 */
				$new_emails =  array_diff( $value, self::$emails );
				do_action( 'ph_new_email_admin_subscribe', $new_emails, $user, $post_id );
			}
		}
	}

	public static function sanitize_field( $field ) {

		$value = isset( $_POST['ph_' . $field['id'] ] ) ? $_POST['ph_' . $field['id'] ] : false;

		switch( $field['type'] ) {
			case 'checkbox':
				$value = $value ? esc_html( $value ) : 'off';
				break;
		}

		if ( is_array( $value ) && ! empty( $value ) ) {
			foreach ( $value as $key => $email ) {
				if ( ! filter_var( trim( $email ), FILTER_VALIDATE_EMAIL ) ) {
					$errors   = get_option( 'ph_meta_errors' );
					$errors[] = __( 'Invalid Email', 'project-huddle' );
					update_option( 'ph_meta_errors', $errors );
					unset( $value[ $key ] );
				}
			}
		}

		return $value;
	}
}