<?php
/**
 * API Functions Parent Classs]
 *
 * Process the API Requests
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       2.1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class PH_Project_Actions_Abstract {
	/**
	 * Add Filter and actions for each function
	 *
	 * @param $name string Function name
	 * @param $data array Data to filter
	 *
	 * @return mixed
	 */
	public function filter_action( $name, $data ) {
		// filter model data
		$data = apply_filters( 'ph_mockup_filter_' . $name, $data );

		// comment action
		do_action( 'ph_after_mockup_' . $name, $this->data );

		return $data;
	}

	/**
	 * Adds user email to project for notifications
	 */
	public function add_email() {
		// get all added emails
		$emails = (array) get_post_meta( (int) $this->data['project_id'], 'ph_project_emails', true );

		// get enabled emails
		$enabled = (array) get_post_meta( (int) $this->data['project_id'], 'ph_project_emails_enable', true );

		// check for user object
		if ( is_object( $this->user ) ) {
			$user = $this->user->user_email;
		}

		// if email hasn't already been added
		if ( ! in_array( $user, $emails ) ) {
			// add user email
			$emails[]  = sanitize_email( $user );
			$enabled[] = sanitize_email( $user );

			// add to total email chain
			update_post_meta( (int) $this->data['project_id'], 'ph_project_emails', array_unique( $emails ) );

			// add to enabled emails
			update_post_meta( (int) $this->data['project_id'], 'ph_project_emails_enable', array_unique( $enabled ) );
		}
	}

	public function send_comment_email() {
		ph_email_image_comment( $this->data['user'], $this->data, $this->data['image_id'], $this->data['project_id'] );
	}
}