<?php
/**
 * Functions for images
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Removes "Protected" and "Private" from the title
 *
 * @since 1.0
 */
function ph_get_the_title( $id = 0 ) {
	global $post;

	$findthese   = array(
		'#Protected:#',
		'#Private:#'
	);
	$replacewith = array(
		'', // What to replace "Protected:" with nothing
		'' // What to replace "Private:" with nothing
	);

	$id = $id ? $id : $post->ID;

	$title = get_the_title( (int) $id );
	$title = preg_replace( $findthese, $replacewith, $title );

	// TODO: sanitation
	return apply_filters( 'ph_get_the_title', $title );
}

/**
 * Convenience function to echo the title
 *
 * @since 1.0
 */
function ph_the_title() {
	echo ph_get_the_title();
}

/**
 * Hides admin bar on project page in place of our own UI.
 *
 * @return bool
 */
function ph_hide_admin_bar( $bool ) {
	if ( is_singular( 'ph-project' ) ) {
		return false;
	}

	return $bool;
}
add_filter( 'show_admin_bar', 'ph_hide_admin_bar' );

/**
 * Creates unique hash id for a specific post id
 *
 * Makes un-guessable unique urls possible.
 *
 * @param int $post_id ID of the post
 * @param int $len     Length of the hash
 *
 * @return string Unique hash for the post
 */
function ph_gen_uuid( $post_id, $len = 8 ) {

	$hex = md5( $post_id . uniqid( "", true ) );

	$pack = pack( 'H*', $hex );
	$tmp  = base64_encode( $pack );

	$uid = preg_replace( "#(*UTF8)[^A-Za-z0-9]#", "", $tmp );

	$len = max( 4, min( 128, $len ) );

	while ( strlen( $uid ) < $len ) {
		$uid .= ph_gen_uuid( 22 );
	}

	return substr( $uid, 0, $len );
}