<?php
/**
 * Misc functions
 *
 * Miscellaneous functions for ProjectHuddle
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Adds an identity body class to prevent style conflicts
 *
 * @param  array $classes array of included body classes
 *
 * @return array          modified array of body classes
 */
function ph_body_class( $classes ) {
// add our body class identity
	$classes[] = 'projecthuddle';

	return $classes;
}

add_filter( 'body_class', 'ph_body_class' );

function ph_get_remote_IP() {
	if ( ! empty( $_SERVER['HTTP_CLIENT_IP'] ) ) {
		return $_SERVER['HTTP_CLIENT_IP'];

	} else if ( ! empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
		return $_SERVER['HTTP_X_FORWARDED_FOR'];
	}

	return $_SERVER['REMOTE_ADDR'];
}

if ( ! function_exists( 'ph_adjust_brightness' ) ) :
    /**
     * ph_adjust_brightness
     */
	function ph_adjust_brightness( $hex, $steps ) {
		// Steps should be between -255 and 255. Negative = darker, positive = lighter
		$steps = max( - 255, min( 255, $steps ) );

		// Normalize into a six character long hex string
		$hex = str_replace( '#', '', $hex );
		if ( strlen( $hex ) == 3 ) {
			$hex = str_repeat( substr( $hex, 0, 1 ), 2 ) . str_repeat( substr( $hex, 1, 1 ), 2 ) . str_repeat( substr( $hex, 2, 1 ), 2 );
		}

		// Split into three parts: R, G and B
		$color_parts = str_split( $hex, 2 );
		$return      = '#';

		foreach ( $color_parts as $color ) {
			$color  = hexdec( $color ); // Convert to decimal
			$color  = max( 0, min( 255, $color + $steps ) ); // Adjust color
			$return .= str_pad( dechex( $color ), 2, '0', STR_PAD_LEFT ); // Make two char hex code
		}

		return $return;
    }
endif;

if ( ! function_exists( 'ph_badge_css' ) ) :
	/**
	 * Badge CSS conversions
	 *
	 * @var $color string Color
	 */
	function ph_badge_css( $color = '#000000' ) {
		list($r, $g, $b) = sscanf($color, "#%02x%02x%02x"); ?>

		background: <?php echo $r && $g && $b ? "rgba($r, $g, $b, 0.1)" : '#f3f3f3'; ?>;
        color: <?php echo esc_html( ph_adjust_brightness( $color, -80) ); ?>;

		<?php
    }
endif;

/*
* Inserts a new key/value before the key in the array.
*
* @param $key
*   The key to insert before.
* @param $array
*   An array to insert in to.
* @param $new_key
*   The key to insert.
* @param $new_value
*   An value to insert.
*
* @return
*   The new array if the key exists, FALSE otherwise.
*
* @see array_insert_after()
*/
function ph_array_insert_before($key, array &$array, $new_key, $new_value) {
	if (array_key_exists($key, $array)) {
		$new = array();
		foreach ($array as $k => $value) {
			if ($k === $key) {
				$new[$new_key] = $new_value;
			}
			$new[$k] = $value;
		}
		return $new;
	}
	return FALSE;
}

/**
 * Inserts a new key/value after the key in the array.
 *
 * @param string $key       The key to insert after.
 * @param array  $array     An array to insert in to.
 * @param string $new_key   The key to insert.
 * @param mixed  $new_value A value to insert.
 *
 * @return array|bool
 */
function ph_array_insert_after( $key, array &$array, $new_key, $new_value ) {
	if ( array_key_exists( $key, $array ) ) {
		$new = array();
		foreach ( $array as $k => $value ) {
			$new[ $k ] = $value;
			if ( $k === $key ) {
				$new[ $new_key ] = $new_value;
			}
		}

		return $new;
	}

	return false;
}

function ph_get_the_user_ip() {
	if ( ! empty( $_SERVER['HTTP_CLIENT_IP'] ) ) {
        //check ip from share internet
		$ip = $_SERVER['HTTP_CLIENT_IP'];
	} elseif ( ! empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
        //to check ip is pass from proxy
		$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
	} else {
		$ip = $_SERVER['REMOTE_ADDR'];
	}
	return apply_filters( 'ph_get_ip', $ip );
}