<?php
/**
 * Project functions
 *
 * Project functions for ProjectHuddle
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Create unique unguessable slugs
 *
 * @param $slug
 * @param $post_ID
 * @param $post_status
 * @param $post_type
 * @param $post_parent
 *
 * @return string
 */
function ph_cross_type_unique_slugs(  $slug, $post_ID, $post_status, $post_type, $post_parent ) {
	// only do our post types
	if ( 'ph-project' != $post_type ) {
		return $slug;
	}

	$post = get_post( $post_ID );

	// if the post hasn't been created yet
	if ( empty( $post->post_name ) ) {
		$slug = ph_generate_unique_hash( $post_ID );
	}

	return $slug;
}

add_filter( 'wp_unique_post_slug', 'ph_cross_type_unique_slugs', 10, 5 );

/**
 * Generate unique 5 digit hash
 *
 * @param int $id     ID to use for hash
 * @param int $length Length of hash
 *
 * @return string
 */
function ph_generate_unique_hash( $id, $length = 6 ) {
	$hex = md5( $id . uniqid( "", true ) );

	$pack = pack( 'H*', $hex );
	$tmp  = base64_encode( $pack );

	$uid = preg_replace( "#(*UTF8)[^A-Za-z0-9]#", "", $tmp );

	$length = max( 4, min( 128, $length ) );

	while ( strlen( $uid ) < $length ) {
		$uid .= ph_gen_uuid( 22 );
	}

	return strtolower(substr( $uid, 0, $length ));
}