<?php
/**
 * Custom Styles from Options
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

function ph_style_options() {

	ob_start();

	do_action( 'ph_style_options_output' ); ?>

	<?php if ( $ph_highlight_color = get_option( 'ph_highlight_color') ) : ?>
		/* Highlight Color */
		.projecthuddle .ph-comment .ph-annotation-dot,
		.projecthuddle .ph-button,
		.projecthuddle .vex-dialog-button,
		.projecthuddle .button-primary,
        .projecthuddle #top-bar .controls .ph-comments-button .ph-count,
		.projecthuddle input[type="submit"],
		.projecthuddle .vex.vex-theme-default .vex-dialog-button.vex-dialog-button-primary,
		.projecthuddle .vex.vex-theme-dialog .vex-dialog-button.vex-dialog-button-primary {
			background: <?php echo apply_filters( 'ph_highlight_color_output', esc_attr( $ph_highlight_color ) ); ?>;
		}
		::selection {
			background: <?php echo apply_filters( 'ph_highlight_color_output', esc_attr( $ph_highlight_color ) ); ?>;
			color: #fff;
		}
        .projecthuddle .ph-comment .ph-comment-inner .ph-comment-text .ph-comment-item a,
        .projecthuddle #ph-comments-panel .ph-comments-container .ph-comment-panel-item .ph-comment-count:before,
        .projecthuddle #ph-comments-panel .ph-comments-container .ph-comment-panel-item .ph-comment-content a,
        .projecthuddle .ph-comment .ph-comment-inner .ph-comment-text a,
        .projecthuddle .ph-comment-panel-item a {
            color: <?php echo apply_filters( 'ph_highlight_color_output', esc_attr( $ph_highlight_color ) ); ?>;
        }
	<?php endif; ?>

	<?php if ( $ph_control_bg_color = get_option( 'ph_control_bg_color') ) : ?>
		/* Controls Background Color */
		.projecthuddle #top-bar .ph-control-upper,
		.projecthuddle #top-bar .controls,
		.projecthuddle #top-bar .controls .ph-select-dropdown,
        .projecthuddle #ph-comments-panel {
			background-color: <?php echo apply_filters( 'ph_controls_bg_color_output', esc_attr( $ph_control_bg_color ) ); ?>
		}
	<?php endif; ?>

	<?php if ( $control_color = get_option( 'ph_control_color') ) : ?>
		/* Controls Color */
		.projecthuddle #top-bar,
		.projecthuddle #top-bar a,
		.projecthuddle #top-bar button,
		.projecthuddle #top-bar .controls .ph-select-dropdown,
		.projecthuddle #top-bar .controls .ph-select-text,
		.projecthuddle #top-bar .controls .ph-select-dropdown .ph-select-content .ph-select-row,
		.projecthuddle #top-bar .controls .ph-select-dropdown .ph-select-content a.ph-select-row,
        .projecthuddle #ph-comments-panel {
			color: <?php echo apply_filters( 'ph_control_color_output', esc_attr( $control_color ) ); ?>
		}
		.projecthuddle #top-bar .controls .ph-control-button {
			border-color: rgba(<?php echo ph_hex2rgba( apply_filters( 'ph_control_color_output', esc_attr( $control_color ) ), 0.35 ); ?>);
		}
	<?php endif; ?>

	<?php if ( $ph_control_hover_color = get_option( 'ph_control_hover_color') ) : ?>
		/* Controls Hover Color */
		.projecthuddle #top-bar .controls a:hover,
		.projecthuddle #top-bar .controls button:hover,
		.projecthuddle #top-bar a:hover,
		.projecthuddle #top-bar .controls .ph-select-dropdown:hover,
		.projecthuddle #top-bar .controls .ph-select-text:hover,
		.projecthuddle #top-bar .controls .ph-select-dropdown .ph-select-content .ph-select-row:hover,
		.projecthuddle #top-bar .controls .ph-select-dropdown .ph-select-content a.ph-select-row:hover {
			color: <?php echo apply_filters( 'ph_control_hover_color_output', esc_attr( $ph_control_hover_color ) ); ?>
		}
	<?php endif; ?>

    <?php if ( $ph_panel_bg_color = get_option('ph_comments_panel_bg_color') ) : ?>
        .projecthuddle #ph-comments-panel {
            background: <?php echo apply_filters( 'ph_comments_panel_bg_color', esc_attr( $ph_panel_bg_color ) ); ?>
        }
    <?php endif; ?>

	<?php if ( $ph_panel_heading_color = get_option('ph_comments_panel_heading_color') ) : ?>
        .projecthuddle #ph-comments-panel .ph-comments-container .ph-comment-panel-item .ph-comment-item-author {
            color: <?php echo apply_filters( 'comments_panel_heading_color', esc_attr( $ph_panel_heading_color ) ); ?>
        }
	<?php endif; ?>

	<?php if ( $ph_panel_text_color = get_option('ph_comments_panel_color') ) : ?>
        .projecthuddle #ph-comments-panel,
        .projecthuddle #ph-comments-panel .ph-comments-container .ph-comment-panel-item .ph-comment-content {
            color: <?php echo apply_filters( 'comments_panel_text_color', esc_attr( $ph_panel_text_color ) ); ?>
        }
	<?php endif; ?>

	<?php if ( $ph_panel_divider_color = get_option('ph_comments_panel_divider_color') ) : ?>
        .projecthuddle #ph-comments-panel .ph-comments-container .ph-comment-panel-item,
        .projecthuddle #ph-comments-panel .ph-comments-container {
            border-color: <?php echo apply_filters( 'comments_panel_divider_color', esc_attr( $ph_panel_divider_color ) ); ?>
        }
	<?php endif; ?>

	<?php if ( $ph_image_tray_bg_color = get_option( 'ph_image_tray_bg_color') ) : ?>
		/* Image Tray Background Color & Color */
		.projecthuddle #ph-thumbs-navigator {
			background-color: <?php echo apply_filters( 'ph_image_tray_bg_color_output', esc_attr( $ph_image_tray_bg_color ) ); ?>;
		}
	<?php endif; ?>

	<?php if ( $ph_image_tray_color = get_option( 'ph_image_tray_color') ) : ?>
		/* Image Tray Color */
		.projecthuddle #ph-thumbs-navigator,
		.projecthuddle #top-bar #ph-thumbs-navigator .ph-thumb-title,
		.projecthuddle #top-bar #ph-thumbs-navigator .ph-thumb-nav-info,
		.projecthuddle #top-bar #ph-thumbs-navigator button {
			color: <?php echo apply_filters( 'ph_image_tray_color_output', esc_attr( $ph_image_tray_color ) ); ?>;
		}
	<?php endif; ?>
<?php

	$out = ob_get_contents();

	ob_end_clean();

	return $out;
}

/**
 * Convert Hex to RGBA
 *
 * @param string $c Hex color
 * @param float  $a Alpha transparency
 *
 * @return string
 */
function ph_hex2rgba( $c, $a ) {
	if ( $c[0] == '#' ) {
		$c = substr( $c, 1 );
	}
	if ( strlen( $c ) == 6 ) {
		list( $r, $g, $b ) = array( $c[0] . $c[1], $c[2] . $c[3], $c[4] . $c[5] );
	} elseif ( strlen( $c ) == 3 ) {
		list( $r, $g, $b ) = array( $c[0] . $c[0], $c[1] . $c[1], $c[2] . $c[2] );
	} else {
		return false;
	}
	$r = hexdec( $r );
	$g = hexdec( $g );
	$b = hexdec( $b );

	return $r . ', ' . $g . ', ' . $b . ', ' . $a;
}
