<?php
/**
 * Scripts
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Register scripts we can use throughout the plugin
 */
function ph_global_scripts() {
	global $post_type;

	$js_dir = PH_PLUGIN_URL . 'assets/js/';
	$css_dir = PH_PLUGIN_URL . 'assets/css/';

	if ( ! in_array( $post_type, ph_get_post_types() ) ) {
		return false;
	}

	// global register scripts
	wp_register_script( 'ph-select2-admin', $js_dir . 'select2-admin.js', array( 'jquery', 'select2' ), PH_VERSION );
	wp_register_script( 'select2', $js_dir . 'includes/select2.full.min.js', array( 'jquery' ), '4.0.2' );
	wp_register_script( 'autosize', $js_dir . 'includes/autosize.min.js', array(), '3.0.2' );
	wp_register_script( 'jquery-placecursoratend', $js_dir . 'includes/jquery.placecursoratend.js', array( 'jquery' ), '1.0', true );
	wp_register_style( 'select2', $css_dir . 'includes/select2.min.css', array(), '4.0.2' );
	wp_register_style( 'ph-select2-admin', $css_dir . 'project-huddle-select2-admin.css', array( 'select2' ), '4.0.2' );

	wp_localize_script('ph-select2-admin', 'phSelect2', array(
		'defaultAvatar' => get_option( 'avatar_default' ),
	) );
}
add_action( 'wp_enqueue_scripts', 'ph_global_scripts', 999999999 );
add_action( 'admin_enqueue_scripts', 'ph_global_scripts', 9999999 );

/**
 * Un-enqueue theme and other plugin styles and loads our plugin styles.
 *
 * Included style handles can be passed via a hook.
 *
 * @since 1.0
 *
 * @return void
 */
function ph_load_styles() {
	global $wp_styles;

	// return for other pages
	if ( ! in_array( get_post_type(), ph_get_post_types() ) ) {
		return;
	}

	if ( ! get_option( 'ph_script_shielding' ) ) {
		// allowed stylesheets on page
		$allowed['styles_allowed'] = apply_filters( 'ph_allowed_styles', array() );

		// un-enqueue all
		foreach ( $wp_styles->queue as $handle ) :
			if ( ! in_array( $handle, $allowed['styles_allowed'] ) ) {
				wp_dequeue_style( $handle );
			}
		endforeach;
	}

	// store css directory
	$css_dir = PH_PLUGIN_URL . 'assets/css/';

	// Use minified libraries if SCRIPT_DEBUG is turned off
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	wp_enqueue_style( 'toastr', $css_dir . 'includes/toastr.min.css', array(), PH_VERSION );
	wp_enqueue_style( 'ionicons', $css_dir . 'includes/ionicons.css', array(), '2.0.0' );
	wp_enqueue_style( 'ph-login-style', $css_dir . 'ph-login' . $suffix . '.css', array(), PH_VERSION );
	wp_enqueue_style( 'project-huddle', $css_dir . 'project-huddle' . $suffix . '.css', array( 'project-huddle-fonts', 'ionicons' ), PH_VERSION );
	wp_enqueue_style( 'project-huddle-fonts', '//fonts.googleapis.com/css?family=Montserrat:400,700|Lato:300,400,700,900', array(), PH_VERSION );

	// add style options
	wp_add_inline_style( 'project-huddle', apply_filters( 'ph_inline_styles', ph_style_options() ) );
}

add_action( 'wp_enqueue_scripts', 'ph_load_styles', 99999999 );

/**
 * Un-enqueue theme and other plugin scripts and loads our plugin scripts
 *
 * @since 1.0
 *
 * @return void
 */
function ph_load_scripts(){
	global $wp_scripts;

	// store javascript directory
	$js_dir = PH_PLUGIN_URL . 'assets/js/';

	// Use minified libraries if SCRIPT_DEBUG is turned off
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	// global register scripts
	wp_register_script( 'autosize', $js_dir . 'includes/autosize.min.js', array(), '3.0.2', true);
	wp_register_script( 'quill', $js_dir . 'includes/quill.min.js', array(), '1.2.0', true);
	wp_register_script( 'js.cookie', $js_dir . 'includes/js.cookie.js', array(), '2.1.4');
	wp_register_script( 'jquery-placecursoratend', $js_dir . 'includes/jquery.placecursoratend.js', array( 'jquery' ), '1.0', true );

	// return for other pages
	if ( ! is_singular('ph-project') ) {
		return;
	}

	if ( ! get_option( 'ph_script_shielding' ) ) {
		$allowed = apply_filters( 'ph_allowed_scripts', array() );

		foreach ( $wp_scripts->queue as $handle ) :
			if ( ! in_array( $handle, $allowed ) ) {
				wp_dequeue_script( $handle );
			}
		endforeach;
	}

	// enqueue main collaborate script
	wp_register_script( 'modernizr', $js_dir . 'includes/modernizr.custom.js', array(), PH_VERSION );
	wp_register_script( 'project-huddle', $js_dir . 'project-huddle' . $suffix . '.js', array( 'jquery', 'underscore', 'backbone', 'wp-backbone', 'quill', 'fastclick' ), PH_VERSION );
	wp_register_script( 'jquery-scrollbar', $js_dir . 'includes/jquery.scrollbar.min.js', array( 'jquery' ), '0.2.6', true );
	wp_register_script( 'toastr', $js_dir . 'includes/toastr.min.js', array(), '2.1.1', true );
	wp_register_script( 'transformicons', $js_dir . 'includes/transformicons.min.js', array(), '0.4.4', true );
	wp_register_script( 'vex', $js_dir . 'includes/vex.combined.min.js', array( 'jquery' ), '2.3.2', true );
	wp_register_script( 'fastclick', $js_dir . 'includes/fastclick.js', array(), '1.0.6', false );

	wp_enqueue_script( 'modernizr' );
	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'jquery-ui-core');
	wp_enqueue_script( 'jquery-ui-draggable' );
	wp_enqueue_script( 'underscore' );
	wp_enqueue_script( 'backbone' );
	wp_enqueue_script( 'wp-backbone' );
	wp_enqueue_script( 'wp-util' );
	wp_enqueue_script( 'heartbeat' );
	wp_enqueue_script( 'toastr' );
	wp_enqueue_script( 'jquery-scrollbar' );
	wp_enqueue_script( 'transformicons' );
	wp_enqueue_script( 'vex' );
	wp_enqueue_script( 'jquery-placecursoratend' );
	wp_enqueue_script( 'fastclick' );
	wp_enqueue_script( 'js.cookie' );
	wp_enqueue_script( 'project-huddle' );

	// localize nonce and admin ajax
	wp_localize_script( 'project-huddle', 'ph', array(
		'ajaxurl' => esc_url( admin_url( 'admin-ajax.php' ) ),
		'api_url' => get_rest_url(),
		'nonce'   => wp_create_nonce( 'wp_rest' ),
		'phNonce' => wp_create_nonce('project-image-nonce')
	));
}
add_action( 'wp_enqueue_scripts', 'ph_load_scripts', 99999999 );

/**
 * PH Shortcodes script
 */
function ph_shortcode_scripts() {
	wp_register_script( 'ph-shortcodes', PH_PLUGIN_URL . 'assets/js/ph-shortcodes.js', array( 'jquery' ), PH_VERSION );
}

add_action( 'wp_enqueue_scripts', 'ph_shortcode_scripts' );

/**
 * Un-enqueue theme and other plugin styles and loads our plugin styles.
 *
 * Included style handles can be passed via a hook.
 *
 * @since 1.0
 */
function ph_shortcode_styles() {
	// store javascript directory
	$css_dir = PH_PLUGIN_URL . 'assets/css/';

	// Use minified libraries if SCRIPT_DEBUG is turned off
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	wp_register_style( 'project-huddle-shortcodes', $css_dir . 'project-huddle-shortcodes' . $suffix . '.css', array(), PH_VERSION );
}

add_action( 'wp_enqueue_scripts', 'ph_shortcode_styles' );