<?php
/**
 * Functions for the templating system.
 *
 * @package     ProjectHuddle
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Adds underscore templates via filter action
 *
 * @uses ph_get_project_info to generate json data for project
 *
 * @since 1.0
 */
function ph_output_project_underscore_templates() {

	// project container and data
	ph_get_template( 'project/project-image-collection.templ.php', array(
		'project_data' => PH()->project->get_project_info()
	) );

	// project image
	ph_get_template( 'project/project-image.templ.php' );

	// controls
	ph_get_template( 'project/control-bar.templ.php' );
	ph_get_template( 'project/controls.templ.php' );
	ph_get_template( 'project/image-thumb.templ.php' );

	// comments
	ph_get_template( 'comment/comment.templ.php' );
	ph_get_template( 'comment/comment-item.templ.php' );

	// dialogs
	ph_get_template( 'dialog/identify-dialog.templ.php' );
	ph_get_template( 'dialog/login-dialog.templ.php' );
	ph_get_template( 'dialog/copy-link-dialog.templ.php' );
	ph_get_template( 'dialog/share-dialog.templ.php' );
}

// add underscore templates
add_action( 'ph_underscore_templates', 'ph_output_project_underscore_templates' );

/**
 * Output admin underscore templates
 */
function ph_output_project_admin_underscore_templates() {
	global $typenow, $pagenow, $adminpage;

	// check correct post type
	if ( 'ph-project' != $typenow ) {
		return false;
	}

	// check correct page
	if ( 'post.php' != $pagenow && 'post-new.php' != $pagenow ) {
		return false;
	}

	ph_get_template( 'admin/image-thumb.templ.php' );
	ph_get_template( 'admin/project-metabox.templ.php', array(
		'project_data' => PH()->project->images()
	) );
	ph_get_template( 'admin/modal-window.templ.php' );
	ph_get_template( 'admin/dialog.templ.php' );
	ph_get_template( 'admin/settings-menu-items.templ.php' );
}

// add underscore templates
add_action( 'print_media_templates', 'ph_output_project_admin_underscore_templates', 9 );