<?php
function ph_plugin_update() {
	if ( get_option( 'ph_db_version' ) != PH_VERSION ) {
		add_action( 'admin_init', 'ph_general_update', 99 );
	}
	// update metadata
	if ( ! get_option( 'ph_update_metadata_2_6_0', false ) ) {
		add_action( 'admin_init', 'ph_update_metadata_2_6_0' );
	}

	if ( ! get_option( 'ph_fix_missing_pages_2_6_0_5', false ) ) {
		add_action( 'admin_init', 'ph_fix_missing_pages_2_6_0_5' );
	}

	if ( ! get_option( 'ph_fix_homepage_link_2_6_0_7', false ) ) {
		add_action( 'admin_init', 'ph_fix_homepage_link_2_6_0_7' );
	}
}

function ph_fix_homepage_link_2_6_0_7() {
	$threads = get_posts( array(
		'post_type'      => 'phw_comment_loc',
		'posts_per_page' => - 1,
		'status'         => 'publish',
		'date_query'     => array(
			'after'  => date( '2017-10-6', strtotime( '-10 days' ) ),
			'before' => date( '2017-10-27' )
		),
		array(
			'key'     => 'website_id',
			'compare' => 'EXISTS',
		),
	) );

	// loop through each thread
	foreach ( $threads as $thread ) {
		if ( ! $thread->parent_id || ! $thread->page_url ) {
			return;
		}

		if ( ! $page_url = get_post_meta( $thread->parent_id, 'page_url', true )) {
			return;
		}

		// normalize for now
		$thread_url = str_replace( 'https', 'http', $thread->page_url );
		$page_url = str_replace( 'https', 'http', $page_url );

		if ( $thread_url != $page_url ) {
			// find existing page
			$items = PHW()->page->get_items( array(
				'page_url' => $thread->page_url,
			) );

			// if page already exists and website project is published
			if ( isset( $items[0] ) && get_post_status( $items[0]['parent_id'] ) === 'publish' ) {
				update_post_meta( $thread->ID, 'parent_id', $items[0]['id'] );
			} else {
				// create page
				$page = PHW()->page->create_item( array(
					'title'     => $thread->page_url,
					'page_url'  => $thread->page_url,
					'parent_id' => $thread->website_id
				) );

				// update thread parent
				update_post_meta( $thread->ID, 'parent_id', $page['id'] );
			}
		}
	}
	update_option( 'ph_fix_homepage_link_2_6_0_7', true );
}

function ph_fix_missing_pages_2_6_0_5() {
	$threads = get_posts( array(
		'post_type'      => 'phw_comment_loc',
		'posts_per_page' => -1,
		'meta_query'     => array(
			array(
				'key'   => 'parent_id',
				'value' => 0
			),
		)
	) );

	foreach ( $threads as $thread ) {
		$page_url = get_post_meta( $thread->ID, 'page_url', true );

		// if we have a page url
		if ( $page_url ) {
			$page_query = new WP_Query( array(
				'post_type'  => 'ph-webpage',
				'meta_query' => array(
					array(
						'key'   => 'page_url',
						'value' => $page_url
					),
				),
				'fields'     => 'ids'
			) );

			$pages = $page_query->posts;

			// if no matching pages, create one
			if ( ! $pages ) {
				// find website with same hostname
				$parsed = parse_url( $page_url );
				$origin = $parsed['scheme'] . '://' . $parsed['host'];
				$origin .= isset( $parsed['port'] ) ? $parsed['port'] : '';
				$website = PHW()->website->get_items( array(
					'website_url' => $origin,
				) );

				// create page
				$page = PHW()->page->create_item( array(
					'title'     => $page_url,
					'page_url'  => $page_url,
					'parent_id' => $website[0]['id']
				) );

				update_post_meta( $thread->ID, 'parent_id', $page['id'] );
			}

			if ( ! empty( $pages ) && is_array( $pages ) ) {
				update_post_meta( $thread->ID, 'parent_id', $pages[0] );
			}
		}
	}

	update_option( 'ph_fix_missing_pages_2_6_0_5', true );
}

function ph_update_metadata_2_6_0() {
	$sites = new WP_Query( array(
		'post_type'      => 'ph-website',
		'posts_per_page' => - 1,
		'fields'         => 'ids',
		'meta_query'     => array(
			'relation' => 'OR',
			array(
				'key'   => 'website_url',
				'value' => 0
			),
			array(
				'key'     => 'website_url',
				'compare' => 'NOT EXISTS'
			)
		)
	) );

	$site_ids = (array) $sites->posts;

	foreach( $site_ids as $id ) {
		// remove prefix
		$website_url = get_post_meta( $id, 'ph_website_url', true );
		update_post_meta( $id, 'website_url', $website_url );

		$pages = get_post_meta( $id, 'ph_webpages', true );

		// we're going to use parents instead
		if ( ! empty( $pages ) ) {
			foreach ( $pages as $page_id => $page_url ) {

				// store generic parent id
				update_post_meta( $page_id, 'parent_id', $id );

				$locations = (array) get_post_meta( $page_id, 'comment_locations', true );

				// update locations parent
				foreach ( $locations as $location ) {
					// use parent instead
					update_post_meta( $location, 'parent_id', $page_id );
				}

				// use page path for just path of page
				update_post_meta( $page_id, 'page_path', $page_url );

				// have absolute url
				update_post_meta( $page_id, 'page_url', trailingslashit( $website_url ) . ltrim( $page_url, '/' ) );
			}
		}
	}
	update_option( 'ph_update_metadata_2_6_0', true );
}

// flush roles on update
function ph_general_update() {
	$roles = new PH_Roles;
	$roles->add_roles();
	$roles->add_caps();

	/* Restore original Post Data */
	wp_reset_postdata();

	// flush rewrite rules
	flush_rewrite_rules();

	// update option
	update_option( "ph_db_version", PH_VERSION );
}
ph_plugin_update();