<?php
/**
 * The Template for displaying the controls
 *
 * Override this template by copying it to your theme or child theme
 *
 * @package     ProjectHuddle
 * @subpackage  templates
 * @copyright   Copyright (c) 2015, Andre Gagnon
 * @since       1.0
 */
?>

<?php global $post; ?>
<?php
// check to make sure we have dropdown items
$display_dropdown = (bool) ( ! (! is_user_logged_in() && ! current_user_can( 'edit_ph-project', $post->ID )
                                && 'off' == get_post_meta( $post->ID, 'ph_project_sharing', true )
                                && 'off' == get_post_meta( $post->ID, 'ph_project_download', true ) ) );
?>

<!-- Versions Icon -->
<script type="text/template" id="tmpl-versions-button">
    <button class="ph-toggle-nav nav-trigger" data-mode="bottom" data-tip="<?php _e( 'Image Versions', 'project-huddle' ); ?>">
        <i class="ph-icon ion-social-buffer"></i>
    </button>
</script>
<!-- Versions Icon -->

<!-- Comments Button -->
<script type="text/template" id="tmpl-comments-button">
    <button class="ph-toggle-comments-panel ph-comments-button" data-mode="bottom" data-tip="<?php _e( 'Comments', 'project-huddle' ); ?>">
        <i class="ph-icon ion-chatboxes"></i>
        <# if ( data.thread_count != 0 ) { #>
            <span class="ph-count">{{ data.thread_count }}</span>
        <# } #>
    </button>
</script>
<!-- Comments Button -->

<!-- Images Button -->
<script type="text/template" id="tmpl-images-button">
    <button class="ph-toggle-nav nav-trigger" data-mode="bottom" data-tip="<?php _e( 'Project Images', 'project-huddle' ); ?>">
        <i class="ph-icon ion-grid"></i>
    </button>
</script>
<!-- Images Button -->

<!-- Comments Panel -->
<script type="text/template" id="tmpl-comments-panel">
    <h4 class="ph-panel-title">
	    <?php _e('Comments', 'project-huddle'); ?>
    </h4>
    <i class="ion-android-close close-panel close-panel-icon"></i>
    <div class="ph-comments-container"></div>
</script>
<!-- Comments Panel -->

<!-- Toggle Image Nav -->
<script type="text/html" id='tmpl-panel-item'>
    <div class="ph-comment-avatar">{{{ data.avatar }}}</div>
    <div class="ph-comment-content">
        <div class="ph-comment-item-author">
            {{ data.comment_author }}
        </div>
        <div class="ph-comment-item-date">
            {{ data.date }}
        </div>
        <div class="ph-comment-count<# if (data.resolved) { #> ph-approved<# } #>">
            {{ data.comment_count - 1 }}
        </div>

        <div class="ph-comment-item-content">
            <# print( _(data.title  ).nl2br() ); #>
        </div>
    </div>
</script>
<!-- Toggle Image Nav -->

<script type="text/template" id="tmpl-settings-dropdown">
	<?php do_action( 'ph_before_control_settings', $post ); ?>

	<?php if ( $display_dropdown ) : ?>
        <span class="ph-settings ph-control ph-dropdown hover-trigger">

			<span class="ph-select-text">
				<i class="ph-icon ion-gear-a"></i>
			</span>

			<span class="ph-select-dropdown ph-right-align ph-hidden">
				<span class="ph-select-content">
					<?php if ( 'off' != get_post_meta( $post->ID, 'ph_project_sharing', true ) ) : ?>
                        <span class="ph-select-row ph-share-trigger">
							<!-- Share  -->
							<i class="ph-icon ion-paper-airplane"></i>
							<span class="ph-control-text">
								<?php _e( 'Share Project', 'project-huddle' ); ?>
							</span>
                            <!-- Share -->
						</span>
					<?php endif; ?>

					<?php if ( 'on' == get_post_meta( $post->ID, 'ph_project_download', true ) ) : ?>
                        <# if ( typeof data.url != 'undefined' ) { #>
							<a class="ph-select-row"
                               href="<?php echo apply_filters( 'ph_mockup_download_link', '{{ data.url }}', $post ); ?>"
                               download="<?php echo apply_filters( 'ph_mockup_download_link', '{{ data.url }}', $post ); ?>"
                               target="_blank">
								<i class="ph-icon ion-android-download"></i>
								<span class="ph-control-text">
									<?php echo apply_filters( 'ph_mockup_download_text', __( 'Download Image', 'project-huddle' ) ); ?>
								</span>
							</a>
						<# } #>
					<?php endif; ?>
					<?php if ( is_user_logged_in() && current_user_can( 'edit_ph-project', get_the_ID() ) ) : ?>
                        <a class="ph-select-row ph-name" href="<?php echo get_edit_post_link(); ?>">
							<i class="ph-icon ion-gear-a"></i>
							<span class="ph-control-text">
								<?php _e( 'Edit Project', 'project-huddle' ); ?>
							</span>
						</a>
					<?php endif; ?>
				</span>
			</span>
		</span>
	<?php endif; ?>
</script>

<script type="text/template" id="tmpl-user-dropdown">
	<?php if ( is_user_logged_in() ) : ?>

		<?php $current_user = wp_get_current_user(); ?>

        <span class="ph-user ph-control ph-dropdown hover-trigger">
			<span class="ph-avatar ph-select-text">
				<?php echo get_avatar( $current_user->ID, 20 ); ?>
			</span>

		</span>

	<?php else: ?>

        <!-- Login Button -->
        <button class="ph-login" data-mode="bottom" data-tip="<?php _e( 'Login', 'project-huddle' ); ?>">
            <i class="ph-icon ion-person"></i>
        </button>
        <!-- Login Button -->

	<?php endif; ?>
</script>

<script type="text/template" id="tmpl-login-avatar">
    <# if (data.avatar && data.user_email) { #>
        {{{ data.avatar }}}
    <# } else { #>
        <span class="ph-login" data-mode="bottom" data-tip="<?php _e('Login', 'project-huddle'); ?>">
            <i class="ph-icon ion-person"></i>
        </span>
    <# } #>
</script>

<script type="text/template" id="tmpl-login-dropdown">
    <# if (data.ID) { #>
        <span class="ph-select-content">
            <span class="ph-name ph-select-row">
                <h2>{{ data.display_name }}</h2>
                <p>{{ data.user_email }}</p>
            </span>

            <a class="ph-profile ph-select-row" href="<?php echo esc_url( admin_url( 'profile.php' ) ); ?>">
                <i class="ph-icon ion-person"></i> <?php _e( 'Profile', 'project-huddle' ); ?>
            </a>

            <a class="ph-action ph-logout ph-select-row" href="<?php echo wp_logout_url( get_permalink() ) ?>">
                <i class="ph-icon ion-log-out"></i> <?php _e( 'Logout', 'project-huddle' ); ?>
            </a>
        </span>
    <# } else if (data.user_email && data.display_name) { #>
        <span class="ph-select-content">
            <span class="ph-name ph-select-row">
                <h2>{{ data.display_name }}</h2>
                <p>{{ data.user_email }}</p>
            </span>

            <span class="ph-action ph-forget-me ph-select-row">
                <i class="ph-icon ion-log-out"></i> <?php _e( 'Log OUt', 'project-huddle' ); ?>
            </span>
        </span>
    <# } #>
</script>

<script type="text/template" id="tmpl-prev-next-buttons">
    <!-- Previous Button -->
    <a href="#" class="ph-prev-trigger ph-prev-button ph-control-button">
        <i class="ph-icon ion-arrow-left-b"></i>
        <span class="button-text"><?php _e( 'Previous', 'project-huddle' ); ?></span>
    </a>
    <!-- Previous Button -->

    <!-- Next Button -->
    <a href="#" class="ph-next-trigger ph-next-button ph-control-button">
        <span class="button-text"><?php _e( 'Next', 'project-huddle' ); ?></span>
        <i class="ph-icon ion-arrow-right-b"></i>
    </a>
    <!-- Next Button -->
</script>